<?php
/**
 * The template for displaying comments.
 *
 * This is the template that displays the area of the page that contains both the current comments
 * and the comment form.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package Yaffo
 * @since 1.2.6
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/*
 * If the current post is protected by a password and
 * the visitor has not yet entered the password we will
 * return early without loading the comments.
 */
if (
	post_password_required() ||
	(
		! comments_open() &&
		! have_comments()
	)
) {
	return;
}

$yaffo_comments_number = get_comments_number();
$yaffo_commenter = $commenter; // phpcs:ignore VariableAnalysis.CodeAnalysis.VariableAnalysis.UndefinedVariable
$yaffo_req = $req; // phpcs:ignore VariableAnalysis.CodeAnalysis.VariableAnalysis.UndefinedVariable
$yaffo_css_classes = 'nebotheme-comments';

if ( ! nebotheme_get_tm( 'spoiler_comments' ) ) {
	$yaffo_css_classes .= ' nebotheme-comments--show';
}

?>
<div class="<?php echo esc_attr( $yaffo_css_classes ); ?>">
	<div id="comments" class="comments-area">
		<h5 class="comments-opener-wrap mb-0">
			<a class="comments-opener" href="#">
				<?php
				if ( have_comments() && $yaffo_comments_number ) {
					printf(
						esc_html(
							/* translators: number of comments */
							_nx(
								'%1$s Comment',
								'%1$s Comments',
								$yaffo_comments_number,
								'comments',
								'yaffo'
							)
						),
						esc_html( number_format_i18n( $yaffo_comments_number ) )
					);
				} else {
					esc_html_e( 'Write Comment', 'yaffo' );
				}
				?>
			</a>
		</h5>
		<?php

		if ( have_comments() ) {
			nebotheme_render_comments_pagination();
			?>
			<ol class="comment-list">
				<?php
				wp_list_comments(
					[
						'callback' => 'nebotheme_comments_callback',
						'end-callback' => '__return_empty_string',
						'style' => 'ol',
						'type' => 'comment',
					]
				);
				?>
			</ol>
			<?php
			nebotheme_render_comments_pagination();
		}

		if ( comments_open() ) {
			$yaffo_form_fields = [
				'author' => '<div class="comment-input-wrap">' .
					'<p class="comment-form-author">' .
					'<input type="text" id="author" name="author" value="' . esc_attr( $yaffo_commenter['comment_author'] ) . '" placeholder="' . esc_attr__( 'Name', 'yaffo' ) . ( ( $yaffo_req ) ? ' *' : '' ) . '"' . ( ( $yaffo_req ) ? ' required' : '' ) . ' />' .
				'</p>',
				'email' => '<p class="comment-form-email">' .
					'<input type="email" id="email" name="email" value="' . esc_attr( $yaffo_commenter['comment_author_email'] ) . '" placeholder="' . esc_attr__( 'Email', 'yaffo' ) . ( ( $yaffo_req ) ? ' *' : '' ) . '"' . ( ( $yaffo_req ) ? ' required' : '' ) . ' />' .
				'</p>',
				'url' => '<p class="comment-form-url">' .
					'<input type="url" id="url" name="url" value="' . esc_attr( $yaffo_commenter['comment_author_url'] ) . '" placeholder="' . esc_attr__( 'Website', 'yaffo' ) . '" />' .
					'</p>' .
				'</div>',
			];

			if ( get_option( 'show_comments_cookies_opt_in' ) ) {
				$yaffo_form_fields['cookies'] = '<p class="comment-form-cookies-consent">' .
					'<input type="checkbox" id="wp-comment-cookies-consent" name="wp-comment-cookies-consent" value="on"' . ( empty( $yaffo_commenter['comment_author_email'] ) ? '' : ' checked="checked"' ) . ' />' .
					'<label for="wp-comment-cookies-consent">' . esc_html__( 'Save my name, email, and website in this browser for the next time I comment.', 'yaffo' ) . '</label>' .
				'</p>';
			}

			comment_form(
				[
					'comment_field' => '<p class="comment-form-comment">' .
						'<textarea name="comment" id="comment" rows="8" placeholder="' . esc_attr__( 'Comment', 'yaffo' ) . '" required></textarea>' .
					'</p>',
					'title_reply_before' => '<h5 id="reply-title" class="comment-reply-title">',
					'title_reply_after' => '</h5>',
					'label_submit' => esc_html__( 'Submit Comment', 'yaffo' ),
					'fields' => $yaffo_form_fields,
				]
			);
		} elseif ( $yaffo_comments_number && post_type_supports( get_post_type(), 'comments' ) ) {
			?>
			<p class="no-comments">
				<?php esc_html_e( 'Comments are closed.', 'yaffo' ); ?>
			</p>
			<?php
		}
		?>
	</div>
</div>
