<?php
/**
 * Class control
 *
 * @package Yaffo
 */

namespace NeboTheme\Yaffo\Admin\MetaBoxes\Controls;

use NeboTheme\Yaffo\Admin\MetaBoxes\Controls\Base;
use NeboTheme\Yaffo\Admin\Meta_Boxes;

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Metabox Image control
 */
class Image extends Base {
	/**
	 * {@inheritDoc}
	 */
	public function get_type() {
		return 'image';
	}

	/**
	 * {@inheritDoc}
	 */
	protected function get_control_attrs() {
		return array_merge(
			parent::get_control_attrs(),
			[
				'type' => 'hidden',
			]
		);
	}

	/**
	 * {@inheritDoc}
	 */
	protected function get_args_default() {
		return array_merge(
			parent::get_args_default(),
			[
				'multiple' => false,
			]
		);
	}

	/**
	 * {@inheritDoc}
	 */
	public function get_value_for_render( $post = null ) {
		$pm_value = parent::get_value_for_render( $post );

		if ( is_array( $pm_value ) ) {
			$pm_value = array_shift( $pm_value );
		}

		return wp_get_attachment_image_url( $pm_value, 'full' );
	}

	/**
	 * {@inheritDoc}
	 */
	public function get_value_for_frontend( $post = null ) {
		$pm_value = parent::get_value_for_frontend( $post );

		if ( $this->is_multiple() ) {
			$pm_value = array_filter( explode( Meta_Boxes::PM_SEPARATOR_VALUE, $pm_value ), 'boolval' );

			if ( is_array( $pm_value ) && empty( $pm_value ) ) {
				$pm_value = false;
			}
		}

		return $pm_value;
	}

	/**
	 * {@inheritDoc}
	 */
	protected function get_wrap_attrs() {
		$attrs = parent::get_wrap_attrs();

		if ( $this->is_multiple() ) {
			$attrs['class'][] = 'is-multiple';
		}

		return $attrs;
	}

	/**
	 * Check if set multiple.
	 */
	protected function is_multiple() {
		return boolval( $this->get_args( 'multiple' ) );
	}

	/**
	 * {@inheritDoc}
	 */
	public function render_content() {
		?>
		<div class="nebotheme-meta-boxes-field-image-items"></div>
		<a href="#" class="nebotheme-meta-boxes-field-image-add components-button is-primary">
			<?php
			if ( $this->is_multiple() ) {
				esc_html_e( 'Add Images', 'yaffo' );
			} else {
				esc_html_e( 'Add Image', 'yaffo' );
			}
			?>
		</a>
		<?php
	}
}
