<?php
/**
 * Class control
 *
 * @package Yaffo
 */

namespace NeboTheme\Yaffo\Admin\MetaBoxes\Controls;

use NeboTheme\YaffoCore\Ajax_Select;
use NeboTheme\Yaffo\Admin\Meta_Boxes;
use NeboTheme\Yaffo\Utils;

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Metabox Select control
 */
class Select extends Base {
	/**
	 * {@inheritDoc}
	 */
	public function get_type() {
		return 'select';
	}

	/**
	 * {@inheritDoc}
	 */
	protected function get_args_default() {
		return array_merge(
			parent::get_args_default(),
			[
				'option_default' => null,
				'multiple' => false,
			]
		);
	}

	/**
	 * {@inheritDoc}
	 */
	protected function ensure_args() {
		parent::ensure_args();

		$this->ensure_default();
		$this->ensure_options();
	}

	/**
	 * Ensure argument 'default'.
	 */
	protected function ensure_default() {
		if ( ! isset( $this->args['option_default'] ) ) {
			$this->args['option_default'] = $this->has_theme_mod_name();
		}

		if ( $this->args['option_default'] && ! isset( $this->args['default'] ) ) {
			$this->args['default'] = Meta_Boxes::PM_VALUE_INHERIT;
		}
	}

	/**
	 * Ensure argument 'options'.
	 */
	protected function ensure_options() {
		$options = Utils::array_merge(
			$this->get_options_default(),
			Utils::get_if_isset( $this->args, 'options', [] )
		);

		if ( $this->has_theme_mod_name() && isset( $options[ Meta_Boxes::PM_VALUE_INHERIT ] ) ) {
			$option_default = $options[ Meta_Boxes::PM_VALUE_INHERIT ];
			$theme_mod = $this->get_theme_mod();

			foreach ( $options as $option => $option_label ) {
				if ( Meta_Boxes::PM_VALUE_INHERIT === $option ) {
					continue;
				}

				if (
					$option === $theme_mod ||
					nebotheme_get_transformed_value( $option ) === $theme_mod ||
					nebotheme_get_transformed_value( $theme_mod ) === $option
				) {
					$option_default = "{$option_label} ({$option_default})";

					break;
				}
			}

			$options[ Meta_Boxes::PM_VALUE_INHERIT ] = $option_default;
		} elseif ( ! empty( $this->args['options'] ) && ! $this->get_args( 'multiple' ) ) {
			$this->args['default'] = array_keys( $this->args['options'] )[0];
		}

		$this->args['options'] = $options;
	}

	/**
	 * Get default options.
	 */
	protected function get_options_default() {
		$options = [];

		if ( $this->args['option_default'] ) {
			$options[ Meta_Boxes::PM_VALUE_INHERIT ] = esc_html__( 'Customize Settings', 'yaffo' );
		}

		return $options;
	}

	/**
	 * Get options.
	 */
	protected function get_options() {
		return $this->get_args( 'options' );
	}

	/**
	 * {@inheritDoc}
	 */
	protected function get_control_attrs() {
		$attrs = parent::get_control_attrs();
		$attrs['type'] = 'select';

		if ( $this->get_args( 'multiple' ) ) {
			$attrs['data-placeholder'] = $this->get_args( 'placeholder', null );
			$attrs['multiple'] = 'multiple';
			$attrs['name'] .= '[]';
		}

		if ( isset( $attrs['value'] ) ) {
			unset( $attrs['value'] );
		}

		return $attrs;
	}

	/**
	 * {@inheritDoc}
	 */
	public function render_field() {
		$ajax_select = $this->get_args( 'ajax_select' );

		if ( $ajax_select ) {
			$ajax_select['value'] = $this->value;

			Ajax_Select::render_select( $ajax_select, $this->get_control_attrs() );
		} else {
			?>
			<select <?php $this->render_attrs(); ?>>
				<?php
				foreach ( $this->get_options() as $option_value => $option_label ) {
					$attr_option = [
						'value' => $option_value,
					];

					if (
						(
							$option_value === $this->value
						) ||
						(
							$this->get_args( 'multiple' ) &&
							is_array( $this->value ) &&
							(
								in_array( $option_value, $this->value, true ) ||
								in_array( (string) $option_value, $this->value, true )
							)
						)
					) {
						$attr_option['selected'] = 'selected';
					}

					echo '<option ' . nebotheme_get_render_attrs( $attr_option ) . '>' .
						esc_html( $option_label ) .
					'</option>';
				}
				?>
			</select>
			<?php
		}
	}
}
