<?php
/**
 * Auto Loader.
 *
 * @package Yaffo
 */

namespace NeboTheme\Yaffo;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Auto Loader class.
 */
final class Autoloader {
	const ALIAS_NAMESPACES = [
		'NeboTheme\\Yaffo\\Modules' => YAFFO_DIR_MODULES,
		'NeboTheme\\Yaffo' => YAFFO_DIR_FRAMEWORK,
	];

	/**
	 * The class constructor
	 */
	public function __construct() {
		spl_autoload_register( [ $this, 'handler' ] );
	}

	/**
	 * Handler auto loader.
	 */
	public function handler( $class ) {
		foreach ( self::ALIAS_NAMESPACES as $alias_namespace => $alias_dir ) {
			if ( false === strpos( $class, $alias_namespace ) ) {
				continue;
			}

			break;
		}

		if ( empty( $alias_dir ) || empty( $alias_namespace ) ) {
			return;
		}

		// does the class use the namespace prefix?
		$len = strlen( $alias_namespace );

		if ( 0 !== strncmp( $alias_namespace, $class, $len ) ) {
			// no, move to the next registered auto-loader.
			return;
		}
		// get the relative class name.
		$relative_class = substr( $class, $len );
		$relative_class = str_replace( '_', '-', $relative_class );

		foreach ( [ 'class', 'trait', 'interface', '' ] as $type ) {
			$prefix_file = '' !== $type ? "{$type}-" : $type;
			$parts = explode( '\\', $relative_class );
			$last = array_pop( $parts );
			$parts[] = $prefix_file . $last;
			$file = implode( '\\', $parts );
			$file = preg_replace(
				[ '/([a-z])([A-Z])/', '/_/', '/\\\/' ],
				[ '$1-$2', '-', DIRECTORY_SEPARATOR ],
				$file
			);

			switch ( $type ) {
				case 'class':
					$exists = class_exists( $class );
					break;
				case 'trait':
					$exists = trait_exists( $class, true );
					break;
				case 'interface':
					$exists = interface_exists( $class );
					break;
			}

			if ( $exists ) {
				return;
			}

			// replace the namespace prefix with the base directory, replace namespace
			// separators with directory separators in the relative class name, append
			// with .php.
			$file = $alias_dir . strtolower( $file ) . '.php';
			$file = str_replace( '\\', DIRECTORY_SEPARATOR, $file );
			$file = str_replace( '/', DIRECTORY_SEPARATOR, $file );

			// if the file exists, require it.
			if ( is_readable( $file ) ) {
				require_once $file;

				return;
			}
		}
	}
}

new Autoloader();
