<?php
/**
 * Ajax Select control
 *
 * @package Yaffo
 */

namespace NeboTheme\Yaffo\Customize\Controls;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

use NeboTheme\Yaffo\Utils;
use NeboTheme\YaffoCore\Ajax_Select as AjaxSelectModule;

/**
 * Ajax Select control class
 */
class Ajax_Select extends Base {
	/**
	 * Control's Type.
	 *
	 * @var string
	 */
	public $type = 'nebotheme-ajax-select';

	/**
	 * The class constructor
	 */
	public function __construct( $manager, $id, $args = [] ) {
		parent::__construct( $manager, $id, $args );

		$this->multiple = Utils::get_if_isset( $args, 'multiple' );
		$this->ajax_select = Utils::get_if_isset( $args, 'ajax_select' );
	}

	/**
	 * {@inheritDoc}
	 */
	public function render_content() {
		parent::render_content();

		$this->input_attrs['id'] = $this->id;
		$this->input_attrs['name'] = "{$this->id}[]";

		if ( $this->multiple ) {
			$this->input_attrs['multiple'] = 'multiple';
		}

		$this->ajax_select['value'] = $this->value();

		list( $link_name, $link_value ) = explode( '=', str_replace( '"', '', $this->get_link() ) );

		$this->input_attrs['data-customize-setting-link'] = $this->id;
		$this->input_attrs[ $link_name ] = $link_value;

		if ( class_exists( AjaxSelectModule::class ) ) {
			AjaxSelectModule::render_select( $this->ajax_select, $this->input_attrs );
		} else {
			nebotheme_render_notification(
				[
					'type' => 'warning',
					'body' => esc_html__( 'Plese activate `Yaffo Core` plugin.', 'yaffo' ),
				]
			);
		}
	}
}
