<?php
/**
 * Appearance
 *
 * @package Yaffo
 */

use NeboTheme\Yaffo\Customize\Customize_Manager;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

nebotheme_customize_fields_appearance();

/**
 * Adds a customize fields with kirki
 *
 * @return void
 */
function nebotheme_customize_fields_appearance() {
	Customize_Manager::add_panel(
		'appearance',
		[
			'title'    => esc_html__( 'Appearance', 'yaffo' ),
			'priority' => 3,
			'icon'     => 'dashicons-admin-appearance',
		]
	);

	nebotheme_customize_fields_colors();
	nebotheme_customize_fields_typography();
}

/**
 * Adds a customize fields with kirki
 *
 * @return void
 */
function nebotheme_customize_fields_colors() {
	$theme_vars = nebotheme_get_theme_vars();

	Customize_Manager::add_section(
		'colors',
		[
			'title' => esc_html__( 'Colors', 'yaffo' ),
			'icon' => 'dashicons-color-picker',
			'panel' => 'appearance',
		]
	);

	Customize_Manager::add_field(
		[
			'label' => esc_html__( 'General', 'yaffo' ),
			'type' => 'nebotheme-popover-start',
			'section' => 'colors',
		]
	);

	Customize_Manager::add_field(
		[
			'type' => 'multicolor',
			'settings' => 'color_general',
			'section' => 'colors',
			'choices' => $theme_vars['color']['primary'],
			'output_by_choices' => [
				'element' => ':root',
				'property' => '--nebotheme-color-{{NAME}}',
				'context' => [ 'front', 'editor' ],
			],
			'theme_export' => true,
		]
	);

	Customize_Manager::add_field(
		[
			'type' => 'nebotheme-popover-end',
			'section' => 'colors',
		]
	);

	Customize_Manager::add_field(
		[
			'label' => esc_html__( 'Header', 'yaffo' ),
			'type' => 'nebotheme-popover-start',
			'section' => 'colors',
		]
	);

	Customize_Manager::add_field(
		[
			'type' => 'multicolor',
			'label' => esc_html__( 'Header Sticky', 'yaffo' ),
			'settings' => 'color_header_sticky',
			'section' => 'colors',
			'choices' => $theme_vars['color']['header_sticky'],
			'default' => false,
			'output_by_choices' => [
				'element' => '.header .header-sticky',
				'property' => '--nebotheme-color-header-{{NAME}}',
			],
			'active_callback' => [
				[
					'setting' => 'header_sticky_enable',
					'operator' => '!=',
					'value' => '',
				],
			],
		]
	);

	Customize_Manager::add_field(
		[
			'type' => 'multicolor',
			'label' => esc_html__( 'Header Top', 'yaffo' ),
			'settings' => 'color_header_top',
			'section' => 'colors',
			'choices' => $theme_vars['color']['header_top'],
			'output_by_choices' => [
				'element' => '.header .header-top',
				'property' => '--nebotheme-color-header-{{NAME}}',
			],
			'theme_export' => true,
		]
	);

	Customize_Manager::add_field(
		[
			'type' => 'multicolor',
			'label' => esc_html__( 'Header Main', 'yaffo' ),
			'settings' => 'color_header_main',
			'section' => 'colors',
			'choices' => $theme_vars['color']['header_main'],
			'output_by_choices' => [
				'element' => '.header .header-main, .header .header-mobile',
				'property' => '--nebotheme-color-header-{{NAME}}',
			],
			'theme_export' => true,
		]
	);

	Customize_Manager::add_field(
		[
			'type' => 'multicolor',
			'label' => esc_html__( 'Menu', 'yaffo' ),
			'settings' => 'color_menu',
			'section' => 'colors',
			'choices' => $theme_vars['color']['menu'],
			'output_by_choices' => [
				'element' => ':root',
				'property' => '--nebotheme-color-menu-{{NAME}}',
			],
			'theme_export' => true,
			'stick' => true,
		]
	);

	Customize_Manager::add_field(
		[
			'type' => 'multicolor',
			'label' => esc_html__( 'Dropdown Menu', 'yaffo' ),
			'settings' => 'color_menu_dropdown',
			'section' => 'colors',
			'choices' => $theme_vars['color']['menu_dropdown'],
			'theme_export' => true,
			'output_by_choices' => [
				'element' => ':root',
				'property' => '--nebotheme-color-menu-dropdown-{{NAME}}',
			],
		]
	);

	Customize_Manager::add_field(
		[
			'type' => 'nebotheme-popover-end',
			'section' => 'colors',
		]
	);

	Customize_Manager::add_field(
		[
			'label' => esc_html__( 'Off-Canvas', 'yaffo' ),
			'type' => 'nebotheme-popover-start',
			'section' => 'colors',
		]
	);

	Customize_Manager::add_field(
		[
			'type' => 'multicolor',
			'settings' => 'color_off_canvas',
			'section' => 'colors',
			'choices' => $theme_vars['color']['off_canvas'],
			'output_by_choices' => [
				'element' => '#nebotheme-off-canvas',
				'property' => '--nebotheme-color-{{NAME}}',
			],
			'theme_export' => true,
		]
	);

	Customize_Manager::add_field(
		[
			'type' => 'multicolor',
			'label' => esc_html__( 'Navigation', 'yaffo' ),
			'settings' => 'color_off_canvas_menu',
			'section' => 'colors',
			'choices' => $theme_vars['color']['off_canvas_menu'],
			'output_by_choices' => [
				'element' => '#nebotheme-off-canvas',
				'property' => '--nebotheme-color-off-canvas-menu-{{NAME}}',
			],
			'stick' => true,
		]
	);

	Customize_Manager::add_field(
		[
			'type' => 'nebotheme-popover-end',
			'section' => 'colors',
		]
	);
}

/**
 * Adds a customize fields with kirki
 *
 * @return void
 */
function nebotheme_customize_fields_typography() {
	$headings_font_types = [
		'font-size',
		'font-family',
		'line-height',
		'letter-spacing',
		'text-transform',
		'variant',
	];

	/* General < */
	Customize_Manager::add_panel(
		'typography',
		[
			'title' => esc_html__( 'Typography', 'yaffo' ),
			'icon' => 'dashicons-editor-italic',
			'panel' => 'appearance',
		]
	);

	Customize_Manager::add_section(
		'typography_general',
		[
			'title' => esc_html__( 'General', 'yaffo' ),
			'panel' => 'typography',
		]
	);

	Customize_Manager::add_field(
		[
			'type' => 'typography',
			'settings' => 'font_primary',
			'theme_export' => true,
			'label' => esc_html__( 'Primary Font', 'yaffo' ),
			'section' => 'typography_general',
			'css_var_selector' => ':root',
			'font_types' => [
				'font-family',
				'font-size',
				'line-height',
				'letter-spacing',
				'variant',
			],
		]
	);

	Customize_Manager::add_field(
		[
			'type' => 'typography',
			'settings' => 'font_secondary',
			'theme_export' => true,
			'label' => esc_html__( 'Secondary Font', 'yaffo' ),
			'description' => esc_html__( 'Used for post meta, captions of images...', 'yaffo' ),
			'section' => 'typography_general',
			'css_var_selector' => ':root',
			'font_types' => [
				'font-family',
				'font-size',
				'line-height',
				'letter-spacing',
				'text-transform',
				'variant',
			],
		]
	);
	/* General > */

	/* Headings < */
	Customize_Manager::add_section(
		'typography_headings',
		[
			'title' => esc_html__( 'Headings', 'yaffo' ),
			'panel' => 'typography',
		]
	);

	foreach ( range( 1, 6 ) as $level ) {
		Customize_Manager::add_field(
			[
				'type' => 'typography',
				'settings' => "font_heading_h{$level}",
				'theme_export' => true,
				'label' => sprintf( esc_html__( 'Heading Level %s', 'yaffo' ), $level ),
				'section' => 'typography_headings',
				'css_var_selector' => ':root',
				'font_types' => $headings_font_types,
			]
		);
	}
	/* Headings > */

	/* Navigation < */
	Customize_Manager::add_section(
		'typography_navigation',
		[
			'title' => esc_html__( 'Navigation', 'yaffo' ),
			'panel' => 'typography',
		]
	);

	Customize_Manager::add_field(
		[
			'type' => 'typography',
			'settings' => 'font_menu',
			'theme_export' => true,
			'label' => esc_html__( 'Menu Font', 'yaffo' ),
			'description' => esc_html__( 'Used for main top level menu elements.', 'yaffo' ),
			'section' => 'typography_navigation',
			'css_var_selector' => ':root',
			'font_types' => [
				'font-family',
				'font-size',
				'letter-spacing',
				'text-transform',
				'variant',
			],
		]
	);

	Customize_Manager::add_field(
		[
			'type' => 'typography',
			'settings' => 'font_submenu',
			'theme_export' => true,
			'label' => esc_html__( 'Submenu Font', 'yaffo' ),
			'description' => esc_html__( 'Used for submenu elements.', 'yaffo' ),
			'section' => 'typography_navigation',
			'css_var_selector' => ':root',
			'font_types' => [
				'font-family',
				'font-size',
				'letter-spacing',
				'text-transform',
				'variant',
			],
		]
	);
	/* Navigation > */

	/* Off-Canvas < */
	Customize_Manager::add_section(
		'typography_off_canvas',
		[
			'title' => esc_html__( 'Off-Canvas', 'yaffo' ),
			'panel' => 'typography',
		]
	);

	Customize_Manager::add_field(
		[
			'type' => 'typography',
			'settings' => 'font_off_canvas_menu',
			'theme_export' => true,
			'label' => esc_html__( 'Menu Font', 'yaffo' ),
			'description' => esc_html__( 'Used for main top level menu elements.', 'yaffo' ),
			'section' => 'typography_off_canvas',
			'css_var_selector' => ':root',
			'font_types' => [
				'font-family',
				'font-size',
				'letter-spacing',
				'text-transform',
				'variant',
			],
		]
	);

	Customize_Manager::add_field(
		[
			'type' => 'typography',
			'settings' => 'font_off_canvas_submenu',
			'theme_export' => true,
			'label' => esc_html__( 'Submenu Font', 'yaffo' ),
			'description' => esc_html__( 'Used for submenu elements.', 'yaffo' ),
			'section' => 'typography_off_canvas',
			'css_var_selector' => ':root',
			'font_types' => [
				'font-family',
				'font-size',
				'letter-spacing',
				'text-transform',
				'variant',
			],
		]
	);
	/* Off-Canvas > */

	/* Elements < */
	Customize_Manager::add_section(
		'typography_elements',
		[
			'title' => esc_html__( 'Elements', 'yaffo' ),
			'panel' => 'typography',
		]
	);

	Customize_Manager::add_field(
		[
			'type' => 'typography',
			'settings' => 'font_button',
			'theme_export' => true,
			'label' => esc_html__( 'Button Font', 'yaffo' ),
			'section' => 'typography_elements',
			'css_var_selector' => ':root',
			'font_types' => [
				'font-family',
				'font-size',
				'letter-spacing',
				'text-transform',
				'variant',
			],
		]
	);

	Customize_Manager::add_field(
		[
			'type' => 'typography',
			'settings' => 'font_input',
			'theme_export' => true,
			'label' => esc_html__( 'Input Field Font', 'yaffo' ),
			'section' => 'typography_elements',
			'css_var_selector' => ':root',
			'font_types' => [
				'font-family',
				'font-size',
				'letter-spacing',
				'variant',
			],
		]
	);

	Customize_Manager::add_field(
		[
			'type' => 'typography',
			'settings' => 'font_quote',
			'theme_export' => true,
			'label' => esc_html__( 'Quote Font', 'yaffo' ),
			'section' => 'typography_elements',
			'css_var_selector' => ':root',
			'font_types' => [
				'font-family',
				'line-height',
				'font-size',
				'letter-spacing',
				'variant',
			],
		]
	);
	/* Elements > */
}
