<?php
/**
 * Header
 *
 * @package Yaffo
 */

use NeboTheme\Yaffo\Customize\Customize_Manager;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

nebotheme_customize_fields_header();

/**
 * Adds a customize fields with kirki
 *
 * @return void
 */
function nebotheme_customize_fields_header() {
	Customize_Manager::add_section(
		'header',
		[
			'title' => esc_html__( 'Header', 'yaffo' ),
			'priority' => 1,
			'icon' => 'dashicons-schedule',
		]
	);

	Customize_Manager::add_field(
		[
			'type' => 'toggle',
			'settings' => 'header_sticky_enable',
			'label' => esc_html__( 'Display Sticky Header?', 'yaffo' ),
			'default' => false,
			'section' => 'header',
		]
	);

	Customize_Manager::add_field(
		[
			'type' => 'slider',
			'settings' => 'header_sticky_height',
			'label' => esc_html__( 'Header Sticky height', 'yaffo' ) . ' (px)',
			'description' => esc_html__( 'Desktop Device', 'yaffo' ),
			'section' => 'header',
			'stick' => true,
			'choices' => [
				'min' => 40,
				'max' => 100,
				'step' => 1,
			],
			'output' => [
				[
					'element' => ':root',
					'property' => '--nebotheme-header-sticky-height',
					'value_pattern' => '$px',
				],
			],
			'theme_export' => true,
			'active_callback' => [
				[
					'setting' => 'header_sticky_enable',
					'operator' => '!=',
					'value' => '',
				],
			],
		]
	);

	Customize_Manager::add_field(
		[
			'type' => 'slider',
			'settings' => 'header_sticky_height_mobile',
			'description' => esc_html__( 'Tablet/Mobile Device', 'yaffo' ),
			'section' => 'header',
			'choices' => [
				'min' => 40,
				'max' => 250,
				'step' => 1,
			],
			'output' => [
				[
					'element' => 'html:root',
					'media_query' => '@media (max-width: ' . yaffo_get_environment()['monitor_tablet'] . 'px)',
					'property' => '--nebotheme-header-sticky-height',
					'value_pattern' => '$px',
				],
			],
			'theme_export' => true,
			'active_callback' => [
				[
					'setting' => 'header_sticky_enable',
					'operator' => '!=',
					'value' => '',
				],
			],
		]
	);

	Customize_Manager::add_field(
		[
			'type' => 'slider',
			'settings' => 'header_top_height',
			'label' => esc_html__( 'Header Top height', 'yaffo' ) . ' (px)',
			'description' => esc_html__( 'Only for desktop', 'yaffo' ),
			'section' => 'header',
			'choices' => [
				'min' => 30,
				'max' => 100,
				'step' => 1,
			],
			'output' => [
				[
					'element' => ':root',
					'property' => '--nebotheme-header-top-height',
					'value_pattern' => '$px',
				],
			],
			'theme_export' => true,
		]
	);

	Customize_Manager::add_field(
		[
			'type' => 'slider',
			'settings' => 'header_main_height',
			'label' => esc_html__( 'Header Main height', 'yaffo' ) . ' (px)',
			'description' => esc_html__( 'Desktop Device', 'yaffo' ),
			'section' => 'header',
			'stick' => true,
			'choices' => [
				'min' => 40,
				'max' => 250,
				'step' => 1,
			],
			'output' => [
				[
					'element' => ':root',
					'property' => '--nebotheme-header-main-height',
					'value_pattern' => '$px',
				],
			],
			'theme_export' => true,
		]
	);

	Customize_Manager::add_field(
		[
			'type' => 'slider',
			'settings' => 'header_main_height_mobile',
			'description' => esc_html__( 'Tablet/Mobile Device', 'yaffo' ),
			'section' => 'header',
			'choices' => [
				'min' => 40,
				'max' => 250,
				'step' => 1,
			],
			'output' => [
				[
					'element' => ':root',
					'media_query' => '@media (max-width: ' . yaffo_get_environment()['monitor_tablet'] . 'px)',
					'property' => '--nebotheme-header-main-height',
					'value_pattern' => '$px',
				],
			],
			'theme_export' => true,
		]
	);
}
