<?php
/**
 * Social Media
 *
 * @package Yaffo
 */

use NeboTheme\Yaffo\Customize\Customize_Manager;
use NeboTheme\Yaffo\Utils;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

nebotheme_customize_fields_site_media();

/**
 * Adds a customize fields with kirki
 *
 * @return void
 */
function nebotheme_customize_fields_site_media() {
	$social_links = nebotheme_get_social_links();
	$partial_refresh = [
		'container_inclusive' => true,
		'selector' => '.nebotheme-social-icons-global',
		'render_callback' => 'nebotheme_render_social_icons_global',
	];

	Customize_Manager::add_section(
		'social_icons_url',
		[
			'title' => esc_html__( 'Social Icons', 'yaffo' ),
			'priority' => 9,
			'icon' => 'dashicons-share',
		]
	);

	Customize_Manager::add_field(
		[
			'label' => esc_html__( 'Social Icons', 'yaffo' ),
			'type' => 'sortable',
			'settings' => 'social_icons_sortable',
			'section' => 'social_icons_url',
			'choices' => nebotheme_social_options(),
			'partial_refresh' => [
				'social_icons_sortable' => $partial_refresh,
			],
		]
	);

	foreach ( $social_links as $social_name => $social ) {
		$settings_name = "{$social_name}_url";
		$label = $social['label'] . ' ' . Utils::get_if_isset( $social, 'label_admin', '' );

		Customize_Manager::add_field(
			[
				'type' => 'text',
				'settings' => $settings_name,
				'label' => $label,
				'section' => 'social_icons_url',
				'stick' => ! ! next( $social_links ),
				'partial_refresh' => [
					$settings_name => $partial_refresh,
				],
				'input_attrs' => [
					'placeholder' => Utils::get_if_isset( $social, 'placeholder', 'https://' ),
				],
				'active_callback' => [
					[
						'setting' => 'social_icons_sortable',
						'operator' => 'contains',
						'value' => $social_name,
					],
				],
			]
		);
	}
}
