<?php
/**
 * Post class.
 *
 * @package Yaffo
 */

namespace NeboTheme\Yaffo\Post;

use NeboTheme\Yaffo\Admin\Meta_Boxes;
use NeboTheme\Yaffo\Traits\Singleton;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Post class.
 */
final class Post {
	use Singleton;

	const PM_READ_TIME = '_nebotheme_read_time';
	const PM_SHARE_COUNT = 'nebotheme_share_count';
	const WPM = 250;

	/**
	 * The class constructor
	 */
	public function __construct() {
		add_action( 'save_post_post', [ $this, 'update_read_time' ], 10, 1 );
	}

	/**
	 * Update read time.
	 */
	public function update_read_time( $post_id ) {
		$read_time = self::get_new_read_time( $post_id );

		update_post_meta( $post_id, self::PM_READ_TIME, $read_time );
	}

	/**
	 * Get new read time.
	 */
	public static function get_new_read_time( $post_id ) {
		$post_content = wp_strip_all_tags(
			strip_shortcodes(
				get_post_field( 'post_content', $post_id )
			)
		);

		$number_of_images = substr_count( strtolower( $post_content ), '<img ' );
		$word_count = count( preg_split( '/\s+/', $post_content ) );

		/* Calculate by Image */
		for ( $i = 1; $i <= $number_of_images; $i++ ) {
			if ( $i >= 10 ) {
				$word_count += 3 * (int) self::WPM / 60;
			} else {
				$word_count += ( 12 - ( $i - 1 ) ) * (int) self::WPM / 60;
			}
		}

		return ceil( $word_count / self::WPM );
	}

	/**
	 * Get read time.
	 */
	public static function get_read_time( $post_id = null ) {
		if ( ! $post_id ) {
			$post_id = get_the_ID();
		}

		$read_time = get_post_meta( $post_id, self::PM_READ_TIME, true );

		if ( ! $read_time ) {
			$read_time = self::get_new_read_time( $post_id );

			update_post_meta( $post_id, self::PM_READ_TIME, $read_time );
		}

		return $read_time;
	}
}
