<?php
/**
 * Class widgets organizer
 *
 * @package Yaffo
 */

namespace NeboTheme\Yaffo\Sidebars;

use NeboTheme\Yaffo\Sidebars\Sidebar_Manager;
use NeboTheme\Yaffo\Traits\Singleton;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Widgets Manager Class
 */
final class Widgets_Manager {
	use Singleton;

	/**
	 * The class constructor
	 *
	 * @return void
	 */
	public function __construct() {
		add_action( 'admin_enqueue_scripts', [ __CLASS__, 'admin_enqueue_scripts' ] );

		add_filter( 'nebotheme_config_admin', [ __CLASS__, 'admin_config' ] );
		add_filter( 'nebotheme_widgets_classes', [ __CLASS__, 'get_widgets_classes' ] );

		add_filter( 'get_archives_link', [ __CLASS__, 'widget_count_span' ] );
		add_filter( 'wp_list_categories', [ __CLASS__, 'widget_count_span' ] );

	}

	/**
	 * Add spans around count text in archive/category widget.
	 */
	public static function widget_count_span( $links ) {
		if ( ! preg_match( '/<\s*option[^>]*>/', $links ) && Sidebar_Manager::is_rendering_sidebar() ) {
			switch ( current_filter() ) {
				case 'get_archives_link':
					$search = '</a>&nbsp;(';
					break;
				case 'wp_list_categories':
					$search = '</a> (';
					break;
			}

			if ( isset( $search ) ) {
				$links = str_replace( $search, '</a><span class="nebotheme-post-count">', $links );
				$links = str_replace( ')', '</span>', $links );
			}
		}

		return $links;
	}

	/**
	 * Data to frontend
	 *
	 * @param array $localize
	 *
	 * @return array
	 */
	public static function admin_config( $localize ) {
		$localize['l10n']['image_button'] = esc_html__( 'Insert In Widget', 'yaffo' );

		return $localize;
	}

	/**
	 * Enqueue scripts styles for admin.
	 *
	 * @return void
	 */
	public static function admin_enqueue_scripts() {
		wp_enqueue_script( 'media-upload' );
		wp_enqueue_media();
	}

	/**
	 * Classes widgets
	 *
	 * @param array $widgets_classes
	 *
	 * @return array
	 */
	public static function get_widgets_classes( array $widgets_classes ) {
		$namespace = __NAMESPACE__ . '\\Widgets\\';

		return $widgets_classes + [
			$namespace . 'About',
			$namespace . 'Author',
			$namespace . 'Featured_Image',
			$namespace . 'Featured_Posts',
			$namespace . 'Post_List',
			$namespace . 'Social_Icons',
		];
	}
}
