<?php
/**
 * Class widget
 *
 * @package Yaffo
 */

namespace NeboTheme\Yaffo\Sidebars\Widgets;

use NeboTheme\YaffoCore\Widget_Base;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Widget class About.
 */
class About extends Widget_Base {
	/**
	 * {@inheritDoc}
	 */
	public static function get_name() {
		return 'about';
	}

	/**
	 * {@inheritDoc}
	 */
	public function get_label() {
		return '⛅ ' . esc_html__( 'NeboTheme - About Me', 'yaffo' );
	}

	/**
	 * {@inheritDoc}
	 */
	public function form( $instance ) {
		$defaults = [
			'autograph' => '',
			'link' => '',
			'image' => '',
			'name' => '',
			'sub_name' => '',
			'description' => '',
			'title' => apply_filters( 'widget_title', empty( $instance['title'] ) ? esc_attr__( 'About Me', 'yaffo' ) : $instance['title'], $instance, $this->id_base ),
		];

		$instance = wp_parse_args( (array) $instance, $defaults );
		?>
		<!-- Title -->
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>">
				<?php esc_html_e( 'Title', 'yaffo' ); ?>:
			</label>
			<input type="text" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" class="widefat title">
		</p>
		<!-- Link -->
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'link' ) ); ?>">
				<?php esc_html_e( 'Link', 'yaffo' ); ?>:
			</label>
			<input type="text" id="<?php echo esc_attr( $this->get_field_id( 'link' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'link' ) ); ?>" value="<?php echo esc_attr( $instance['link'] ); ?>" placeholder="<?php echo esc_attr( 'https://' ); ?>" class="widefat"><br>
			<small>
				<?php esc_html_e( 'Enter a link to which you want the image about me to go.', 'yaffo' ); ?>
			</small>
		</p>
		<!-- Image src -->
		<?php $this->render_field_image( $instance, 'image', esc_html__( 'Avatar', 'yaffo' ) ); ?>
		<!-- Name -->
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'name' ) ); ?>">
				<?php esc_html_e( 'Name', 'yaffo' ); ?>:
			</label>
			<input type="text" id="<?php echo esc_attr( $this->get_field_id( 'name' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'name' ) ); ?>" value="<?php echo esc_attr( $instance['name'] ); ?>" class="widefat">
		</p>
		<!-- Sub Name -->
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'sub_name' ) ); ?>">
				<?php esc_html_e( 'Sub Name', 'yaffo' ); ?>:
			</label>
			<input type="text" id="<?php echo esc_attr( $this->get_field_id( 'sub_name' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'sub_name' ) ); ?>" value="<?php echo esc_attr( $instance['sub_name'] ); ?>" class="widefat">
		</p>
		<!-- Description -->
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'description' ) ); ?>">
				<?php esc_html_e( 'About me text', 'yaffo' ); ?>:
			</label>
			<textarea id="<?php echo esc_attr( $this->get_field_id( 'description' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'description' ) ); ?>" rows="4" class="widefat"><?php echo esc_textarea( $instance['description'] ); ?></textarea>
		</p>
		<!-- Autograph Image URL -->
		<?php
		$this->render_field_image( $instance, 'autograph', esc_html__( 'Autograph', 'yaffo' ) );
	}

	/**
	 * {@inheritDoc}
	 */
	protected function render( $args, $instance ) {
		$instance = wp_parse_args(
			$instance,
			[
				'autograph' => '',
				'link' => '',
				'title' => '',
				'image' => '',
				'name' => '',
				'sub_name' => '',
				'description' => '',
			]
		);

		echo '<div class="nebotheme-about">';

		$this->render_inner( $instance );

		echo '</div>';
	}

	/**
	 * Echoes the widget content inner.
	 */
	protected function render_inner( $instance ) {
		if ( $instance['image'] ) {
			$is_link = ! ! $instance['link'];
			$link_tag = $is_link ? 'a' : 'span';
			$link_attr = [];

			if ( $is_link ) {
				$link_attr['href'] = $instance['link'];
			}

			echo '<div class="about-image">' .
				'<' . esc_attr( $link_tag ) . ' ' . nebotheme_get_render_attrs( $link_attr ) . '>';

			if ( isset( $instance['image']['html'] ) ) {
				echo nebotheme_get_kses_content( $instance['image']['html'] );
			} else {
				$this->render_image( $instance, 'image' );
			}

				echo '</' . esc_attr( $link_tag ) . '>' .
			'</div>';
		}

		if ( $instance['name'] ) {
			echo '<h3 class="about-name">' .
				'<span>' . esc_html( $instance['name'] ) . '</span>' .
			'</h3>';
		}

		if ( $instance['sub_name'] ) {
			echo '<p class="about-sub-name">' .
					'<span>' . esc_html( $instance['sub_name'] ) . '</span>' .
			'</p>';
		}

		if ( $instance['description'] ) {
			echo '<div class="about-description">' .
				'<p>' .
					nebotheme_get_kses_content( $instance['description'] ) .
				'</p>' .
			'</div>';
		}

		if ( $instance['autograph'] ) {
			echo '<div class="about-autograph">';

			$this->render_image( $instance, 'autograph' );

			echo '</div>';
		}
	}
}
