<?php
/**
 * Class widget
 *
 * @package Yaffo
 */

namespace NeboTheme\Yaffo\Sidebars\Widgets;

use NeboTheme\Yaffo\Sidebars\Widgets\About;
use NeboTheme\Yaffo\Utils;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Widget class About.
 */
class Author extends About {
	/**
	 * {@inheritDoc}
	 */
	public static function get_name() {
		return 'author';
	}

	/**
	 * {@inheritDoc}
	 */
	public function get_label() {
		return '⛅ ' . esc_html__( 'NeboTheme - About Author', 'yaffo' );
	}

	/**
	 * {@inheritDoc}
	 */
	public static function is_ready( $sidebar_id = null ) {
		if ( ! is_singular() ) {
			return false;
		}

		return parent::is_ready( $sidebar_id );
	}

	/**
	 * {@inheritDoc}
	 */
	public function update( $new_instance, $old_instance ) {
		if ( ! isset( $new_instance['show_social_icons'] ) ) {
			$new_instance['show_social_icons'] = '';
		}

		$instance = parent::update( $new_instance, $old_instance );

		return $instance;
	}

	/**
	 * {@inheritDoc}
	 */
	public function form( $instance ) {
		$defaults = [
			'title' => apply_filters( 'widget_title', empty( $instance['title'] ) ? esc_attr__( 'About Author', 'yaffo' ) : $instance['title'], $instance, $this->id_base ),
			'show_social_icons' => '',
		];

		$instance = wp_parse_args( (array) $instance, $defaults );
		?>
		<!-- Title -->
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>">
				<?php esc_html_e( 'Title', 'yaffo' ); ?>:
			</label>
			<input type="text" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" class="widefat title">
		</p>
		<!-- Social Icons -->
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'show_social_icons' ) ); ?>">
				<?php esc_html_e( 'Show social icons', 'yaffo' ); ?>
			</label>
			<input class="checkbox" type="checkbox"<?php checked( (bool) $instance['show_social_icons'] ); ?> id="<?php echo esc_attr( $this->get_field_id( 'show_social_icons' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'show_social_icons' ) ); ?>" />
		</p>
		<?php
	}

	/**
	 * {@inheritDoc}
	 */
	protected function render_inner( $instance ) {
		$user_id = get_the_author_meta( 'ID' );

		if ( ! $user_id ) {
			return;
		}

		$socials = nebotheme_get_social_author();
		$sub_name = get_the_author_meta( 'briefly', $user_id );

		if ( ! $sub_name ) {
			$roles = get_the_author_meta( 'roles', $user_id );

			if ( $roles ) {
				$roles = (array) $roles;
				$editable_roles = wp_roles()->roles;
				$first_role = $roles[0];

				if ( isset( $editable_roles[ $first_role ]['name'] ) ) {
					$sub_name = translate_user_role( $editable_roles[ $first_role ]['name'] );
				}
			}
		}

		$instance = Utils::array_merge_safe(
			$instance,
			[
				'autograph' => '',
				'show_social_icons' => '',
				'link' => get_author_posts_url( $user_id ),
				'title' => '',
				'image' => [
					'html' => get_avatar( $user_id, '300' ),
				],
				'name' => get_the_author_meta( 'display_name', $user_id ),
				'sub_name' => $sub_name,
				'description' => get_the_author_meta( 'description', $user_id ),
			]
		);

		parent::render_inner( $instance );

		if ( $instance['show_social_icons'] ) {
			?>
			<div class="author-links">
				<?php nebotheme_render_social_icons( $socials ); ?>
			</div>
			<?php
		}
	}
}
