<?php
/**
 * Class widget
 *
 * @package Yaffo
 */

namespace NeboTheme\Yaffo\Sidebars\Widgets;

use NeboTheme\YaffoCore\Widget_Base;
use NeboTheme\Yaffo\Utils;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Widget class Featured_Image.
 */
class Featured_Image extends Widget_Base {
	/**
	 * {@inheritDoc}
	 */
	public static function get_name() {
		return 'featured_image';
	}

	/**
	 * {@inheritDoc}
	 */
	public function get_label() {
		return '⛅ ' . esc_html__( 'NeboTheme - Featured Image', 'yaffo' );
	}

	/**
	 * {@inheritDoc}
	 */
	public function update( $new_instance, $old_instance ) {
		$new_instance['image_ratio'] = Utils::get_if_isset( $new_instance, 'image_ratio', '' );

		if ( is_numeric( $new_instance['image_ratio'] ) ) {
			$new_instance['image_ratio'] = round( (float) $new_instance['image_ratio'], 2 );

			if ( 0.3 > $new_instance['image_ratio'] ) {
				$new_instance['image_ratio'] = 0.3;
			} elseif ( 1.5 < $new_instance['image_ratio'] ) {
				$new_instance['image_ratio'] = 1.5;
			}
		}

		$instance = parent::update( $new_instance, $old_instance );

		return $instance;
	}

	/**
	 * {@inheritDoc}
	 */
	public function form( $instance ) {
		$defaults = [
			'title' => '',
			'label' => esc_attr__( 'Featured Image', 'yaffo' ),
			'link' => '',
			'image_ratio' => '',
		];

		$instance = Utils::array_merge_safe( (array) $instance, $defaults );
		?>
		<!-- Title -->
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>">
				<?php esc_html_e( 'Title', 'yaffo' ); ?>:
			</label>
			<input type="text" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" class="title widefat">
		</p>
		<!-- Label -->
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'label' ) ); ?>">
				<?php esc_html_e( 'Label', 'yaffo' ); ?>:
			</label>
			<input type="text" id="<?php echo esc_attr( $this->get_field_id( 'label' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'label' ) ); ?>" value="<?php echo esc_attr( $instance['label'] ); ?>" class="widefat">
		</p>
		<!-- Image -->
		<?php $this->render_field_image( $instance ); ?>
		<!-- Image Ratio -->
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'image_ratio' ) ); ?>">
				<?php esc_html_e( 'Image Ratio', 'yaffo' ); ?>:
			</label>
			<input type="number" id="<?php echo esc_attr( $this->get_field_id( 'image_ratio' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'image_ratio' ) ); ?>" value="<?php echo esc_attr( $instance['image_ratio'] ); ?>" step="0.05" min="0.3" max="1.5" placeholder="0.55" class="widefat">
		</p>
		<!-- Link -->
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'link' ) ); ?>">
				<?php esc_html_e( 'Link', 'yaffo' ); ?>:
			</label>
			<input type="text" id="<?php echo esc_attr( $this->get_field_id( 'link' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'link' ) ); ?>" value="<?php echo esc_attr( $instance['link'] ); ?>" placeholder="<?php echo esc_attr( 'https://' ); ?>" class="widefat">
		</p>
		<?php
	}

	/**
	 * {@inheritDoc}
	 */
	protected function render( $args, $instance ) {
		nebotheme_render_featured_image(
			[
				'image_id' => Utils::get_if_isset( $instance, 'image', '' ),
				'image_size' => Utils::get_if_isset( $instance, 'image_size', 'full' ),
				'label' => $instance['label'],
				'url' => $instance['link'],
				'ratio' => Utils::get_if_isset( $instance, 'image_ratio', '' ),
			]
		);
	}
}
