<?php
/**
 * Class widget
 *
 * @package Yaffo
 */

namespace NeboTheme\Yaffo\Sidebars\Widgets;

use NeboTheme\YaffoCore\Widget_Base;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Widget class Social_Icons.
 */
class Social_Icons extends Widget_Base {

	/**
	 * {@inheritDoc}
	 */
	public static function is_active() {
		return nebotheme_is_render_social_icons();
	}

	/**
	 * {@inheritDoc}
	 */
	public static function get_name() {
		return 'social_icons';
	}

	/**
	 * {@inheritDoc}
	 */
	public function get_label() {
		return '⛅ ' . esc_html__( 'NeboTheme - Social Icons', 'yaffo' );
	}

	/**
	 * {@inheritDoc}
	 */
	public function update( $new_instance, $old_instance ) {
		$social_options = nebotheme_social_options();
		$instance = parent::update( $new_instance, $old_instance );

		foreach ( $social_options as $type => $label ) {
			if ( isset( $instance[ $type ] ) ) {
				continue;
			}

			$instance[ $type ] = '';
		}

		return $instance;
	}

	/**
	 * {@inheritDoc}
	 */
	public function form( $instance ) {
		$social_options = nebotheme_social_options();
		$social_icons_sortable = nebotheme_get_social_icons_sortable();
		$instance_defaults = [
			'title' => apply_filters( 'widget_title', empty( $instance['title'] ) ? esc_attr__( 'Social Icons', 'yaffo' ) : $instance['title'], $instance, $this->id_base ),
		];

		foreach ( $social_options as $type => $label ) {
			if ( isset( $instance[ $type ] ) ) {
				continue;
			}

			$instance_defaults[ $type ] = in_array( $type, $social_icons_sortable, true ) ? 'on' : null;
		}

		$instance = wp_parse_args( (array) $instance, $instance_defaults );
		?>
		<!-- Title -->
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title', 'yaffo' ); ?>:</label>
			<input type="text" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" class="widefat title">
		</p>
		<div class="social-widget-wrap">
			<?php
			foreach ( $social_options as $type => $label ) {
				$url = nebotheme_get_social_url( $type );
				?>
				<p>
					<input type="checkbox" id="<?php echo esc_attr( $this->get_field_id( $type ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( $type ) ); ?>" title="<?php echo esc_attr( $url ); ?>" <?php checked( (bool) $instance[ $type ], true ); ?>>
					<label for="<?php echo esc_attr( $this->get_field_id( $type ) ); ?>" title="<?php echo esc_attr( $url ); ?>">
						<?php echo esc_html( $label ); ?>
					</label>
				</p>
				<?php
			}
			?>
		</div>
		<!-- Go to settings -->
		<p>
			<a target="_blank" href="<?php echo esc_url( admin_url( '/admin.php?page=social_icons_url' ) ); ?>">
				<?php esc_html_e( 'Social Settings', 'yaffo' ); ?>
			</a>
		</p>
		<?php
	}

	/**
	 * {@inheritDoc}
	 */
	protected function render( $args, $instance ) {
		$social_icons = [];

		foreach ( nebotheme_social_options() as $type => $label ) {
			if ( ! empty( $instance[ $type ] ) ) {
				$social_icons[] = $type;
			}
		}

		if ( ! $social_icons ) {
			return;
		}

		$socials = [];

		foreach ( $social_icons as $social_icon ) {
			$socials[] = [
				'url' => nebotheme_get_social_url( $social_icon ),
				'icon' => nebotheme_get_social_data( $social_icon, 'icon' ),
				'label' => nebotheme_get_social_data( $social_icon, 'label' ),
			];
		}

		nebotheme_render_social_icons( $socials );
	}
}
