<?php
/**
 * Organizer theme default
 *
 * @package Yaffo
 */

namespace NeboTheme\Yaffo\ThemeData;

use NeboTheme\Yaffo\Traits\Singleton;
use NeboTheme\Yaffo\Customize\Customize_Manager;

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Class organizer theme default
 */
final class Default_Manager {
	use Singleton;

	/**
	 * Get theme default data.
	 *
	 * @var array
	 */
	private static $default = [];

	const CONTROL_DEFAULT = [
		'background' => [
			'background-attachment' => 'scroll',
			'background-position' => 'center center',
			'background-repeat' => 'repeat',
			'background-size' => 'cover',
		],
		'typography' => [
			'font-family' => 'Roboto',
			'font-size' => '15px',
			'letter-spacing' => '0px',
			'line-height' => '1.5',
			'text-transform' => 'none',
			'variant' => 'regular',
		],
		'repeater' => [],
		'sortable' => [],
	];

	/**
	 * The class constructor
	 */
	protected function __construct() {
		add_action( 'after_setup_theme', [ $this, 'update_lang' ], 9999 );
	}

	/**
	 * Register support for various WordPress features.
	 */
	public function update_lang() {
		static::$default = [];

		static::get_data();
	}



	/**
	 * Get theme-mods by added fields.
	 */
	public static function get_theme_mods() {
		$fields = Customize_Manager::get_fields();
		$theme_mods = [];

		foreach ( $fields as $field_name => $field_args ) {
			$theme_mod = nebotheme_get_tm( $field_name );

			if ( ! $theme_mod ) {
				continue;
			}

			$theme_mods[ $field_name ] = $theme_mod;
		}

		return $theme_mods;
	}

	/**
	 * Get theme-mods by added fields for export.
	 */
	public static function get_theme_mods_export() {
		$fields = Customize_Manager::get_fields();
		$theme_mods_import = static::get_theme_mods();
		$theme_mods_export = [];

		foreach ( $theme_mods_import as $theme_mod_name => $theme_mod ) {
			if (
				empty( $fields[ $theme_mod_name ] ) ||
				empty( $fields[ $theme_mod_name ]['theme_export'] )
			) {
				continue;
			}

			$theme_mods_export[ $theme_mod_name ] = $theme_mod;
		}

		return $theme_mods_export;
	}


	/**
	 * Get theme default data.
	 */
	public static function get_data() {
		if ( static::$default ) {
			return static::$default;
		}

		$theme_mods = yaffo_get_environment()['theme_mods_default'];
		$theme_mods_default = apply_filters( 'nebotheme_default_theme_mods', [] );

		static::$default = [
			'theme_mods' => array_merge( $theme_mods_default, $theme_mods ),
			'theme_vars' => apply_filters( 'nebotheme_default_theme_vars', [] ),
		];

		return static::$default;
	}
}
