<?php
/**
 * Singleton trait.
 *
 * @package Yaffo
 */

namespace NeboTheme\Yaffo\Traits;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Singleton trait.
 *
 * Ensures only one instance of the trait base class is loaded
 * or can be loaded.
 *
 * @since 1.0.0
 */
trait Singleton {

	/**
	 * Base class instance.
	 *
	 * Holds the trait base class instance.
	 *
	 * @since 1.0.0
	 * @static
	 *
	 * @var array Array with instance of the base class.
	 */
	protected static $instance = [];

	/**
	 * Get instance of base class.
	 *
	 * Ensures only one instance of the base class is loaded or can be loaded.
	 *
	 * @since 1.0.0
	 * @static
	 *
	 * @return object Single instance of the base class.
	 */
	final public static function instance() {
		/**
		 * Returns name of the class the static method is called in.
		 */
		$called_class = get_called_class();

		if ( ! isset( static::$instance[ $called_class ] ) ) {
			static::$instance[ $called_class ] = new $called_class();
		}

		return static::$instance[ $called_class ];
	}
}
