<?php
/**
 * Template Functions.
 *
 * Functions components.
 *
 * @package Yaffo
 */

use NeboTheme\Yaffo\Utils;
use NeboTheme\YaffoCore\Lazy_Load;
use NeboTheme\Yaffo\Classes\WP_Query_Agent;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Echoes copyright
 *
 * @return void
 */
function nebotheme_footer_copyright() {
	$copyright = nebotheme_get_tm( 'footer_copyright' );

	echo '<div class="copyright">';

	if ( function_exists( 'the_privacy_policy_link' ) ) {
		the_privacy_policy_link( '', '. ' );
	}

	echo nebotheme_get_kses_content( stripslashes( $copyright ) ) .
	'</div>';
}
/**
 * Check render social icons.
 *
 * @return boll
 */
function nebotheme_is_render_social_icons() {
	return nebotheme_is_core_active();
}

/**
 * Echoes Social Icons
 *
 * @param array $socials
 *
 * @return void
 */
function nebotheme_render_social_icons( array $socials = [] ) {
	if ( ! nebotheme_is_render_social_icons() || ! $socials ) {
		return;
	}

	$social_default = [
		'url' => '#',
		'title' => '',
		'label' => '',
		'icon' => '',
		'svg' => '',
	];

	echo '<div class="nebotheme-social-icons">' .
	'<div class="nebotheme-social-icons__inner">';

	foreach ( $socials as $social ) {
		$social = Utils::array_merge_safe( $social, $social_default );

		if ( is_email( $social['url'] ) ) {
			$social['url'] = 'mailto:' . antispambot( $social['url'] );
		}

		if ( ( empty( $social['url'] ) || '#' === $social['url'] ) && 'nebotheme-icon-rss' === $social['icon'] ) {
			$social['url'] = get_bloginfo( 'rss_url' );
		}

		$attrs = [
			'href' => $social['url'],
			'rel' => 'nofollow',
			'class' => [],
		];

		if ( $social['title'] ) {
			$attrs['title'] = $social['title'];
		}

		if ( $social['icon'] ) {
			$attrs['class'][] = $social['icon'];
		}

		if ( '#' !== $social['url'] ) {
			$attrs['target'] = '_blank';
		}

		echo '<a ' . nebotheme_get_render_attrs( $attrs ) . '>';

		if ( ! $social['icon'] ) {
			if ( $social['svg'] ) {
				echo nebotheme_get_kses_content( $social['svg'] );
			}
		}

		if ( $social['label'] ) {
			echo '<span>' . esc_html( $social['label'] ) . '</span>';
		}

		echo '</a>';
	}

	echo '</div>' .
	'</div>';
}

/**
 * Echoes Social Icons Global
 *
 * @return void
 */
function nebotheme_render_social_icons_global() {
	if ( ! nebotheme_is_render_social_icons() ) {
		return;
	}

	$socials_sortable = nebotheme_get_social_icons_sortable();

	if ( empty( $socials_sortable ) && ! is_customize_preview() ) {
		return;
	}
	$socials = [];

	foreach ( $socials_sortable as $type ) {
		$socials[] = [
			'url' => nebotheme_get_social_url( $type ),
			'icon' => nebotheme_get_social_data( $type, 'icon' ),
			'svg' => nebotheme_get_social_data( $type, 'svg' ),
			'title' => nebotheme_get_social_data( $type, 'label' ),
		];
	}

	echo '<div class="nebotheme-social-icons-global">';

	nebotheme_render_social_icons( $socials );

	echo '</div>';
}

/**
 * Echoes Button
 *
 * @param array $args
 *
 * @return void
 */
function nebotheme_render_button( array $args = [] ) {
	$args_default = [
		'after' => null,
		'before' => null,
		'full-width' => false,
		'href' => '#',
		'icon' => null,
		'id' => null,
		'styles' => [],
		'target' => '_self',
		'text' => null,
	];
	$args = array_merge( $args_default, $args );
	$attrs = [
		'id' => $args['id'],
		'href' => $args['href'],
		'class' => [
			'nebotheme-button',
			$args['icon'],
		],
	];

	if ( $args['target'] && '_self' !== $args['target'] ) {
		$attrs['target'] = $args['target'];
	}

	if ( ! empty( $args['styles'] ) ) {
		if ( ! is_array( $args['styles'] ) ) {
			$args['styles'] = [ $args['styles'] ];
		}

		foreach ( $args['styles'] as $style ) {
			$attrs['class'][] = "nebotheme-button--{$style}";
		}
	}

	echo '<a ' . nebotheme_get_render_attrs( $attrs ) . '>';

	if ( $args['before'] ) {
		echo nebotheme_get_kses_content( $args['before'] );
	}

	if ( $args['text'] ) {
		echo '<span class="nebotheme-button__text">' . esc_html( $args['text'] ) . '</span>';
	}

	if ( $args['after'] ) {
		echo nebotheme_get_kses_content( $args['after'] );
	}

	echo '</a>';
}

/**
 * Echoes notification
 *
 * @param array $args
 *
 * @return void
 */
function nebotheme_render_notification( array $args = [] ) {
	$args_default = [
		'type' => 'info',
		'title' => null,
		'body' => '',
	];
	$args = wp_parse_args( $args, $args_default );

	if ( 'admin' === $args['title'] ) {
		$args['title'] = esc_attr__( 'This message is visible only to admins', 'yaffo' );
	}

	$attr = [
		'data-type' => $args['type'],
		'title' => $args['title'],
		'class' => [
			'nebotheme-notification',
		],
	];

	echo '<div ' . nebotheme_get_render_attrs( $attr ) . '>';

	if ( is_callable( $args['body'] ) ) {
		call_user_func( $args['body'] );
	} else {
		echo nebotheme_get_kses_content( $args['body'] );
	}

	echo '</div>';
}

/**
 * Echoes trigger button with event name
 *
 * @param string|array $event_chain
 * @param string $classes
 *
 * @return void
 */
function nebotheme_render_trigger( $event_chain, $classes = null, $inner_html = '' ) {
	if ( is_array( $event_chain ) ) {
		$event_chain = join( ':', array_filter( $event_chain ) );
	}

	$attrs = [
		'href' => '#',
		'class' => [
			'nebotheme-trigger',
			'nebotheme-icon-margin',
			$classes,
		],
		'data-event' => $event_chain,
	];

	echo '<a ' . nebotheme_get_render_attrs( $attrs ) . '>';

	if ( $inner_html ) {
		echo nebotheme_get_kses_content( $inner_html );
	}

	echo '</a>';
}

/**
 * Echoes trigger button with event name
 *
 * @param string|array $event_chain
 *
 * @return void
 */
function nebotheme_render_trigger_close( $event_chain ) {
	echo '<a class="nebotheme-trigger nebotheme-trigger-close" title="' . esc_attr__( 'Close', 'yaffo' ) . '" href="#" data-event="' . esc_attr( $event_chain ) . '">' .
		'<div>' .
			'<span></span>' .
			'<span></span>' .
		'</div>' .
	'</a>';
}

/**
 * Echoes Featured Image
 *
 * @param array $args
 *
 * @return void
 */
function nebotheme_render_featured_image( array $args = [] ) {
	static $args_default = null;

	if ( null === $args_default ) {
		$args_default = [
			'image_id' => 0,
			'image_size' => 'yaffo-square',
			'label' => esc_html__( 'Featured Image', 'yaffo' ),
			'url' => '#',
			'ratio' => '',
			'src' => nebotheme_get_placeholder_image_url( [
				'text' => get_bloginfo( 'name' ),
			] ),
		];
	}

	$args = array_replace_recursive( $args_default, $args );

	if ( ! $args['src'] && ! $args['image_id'] ) {
		return;
	}

	$link_attrs = [
		'href' => $args['url'],
	];
	$attrs = [
		'class' => 'nebotheme-featured-image',
	];
	$parsed_url = wp_parse_url( $args['url'] );
	$host_url = Utils::get_if_isset( $parsed_url, 'host' );

	if (
		'#' !== $args['url'] &&
		(
			! $host_url ||
			wp_parse_url( home_url() )['host'] !== $host_url
		)
	) {
		$link_attrs['target'] = '_blank';
	}

	if ( $args['ratio'] ) {
		$attrs['style'] = "--nebotheme-featured-image-ratio: {$args['ratio']}";
	}

	echo '<div ' . nebotheme_get_render_attrs( $attrs ) . '>' .
	'<a ' . nebotheme_get_render_attrs( $link_attrs ) . '>';

	nebotheme_render_attachment( [
		'alt' => $args['label'],
		'id' => $args['image_id'],
		'size' => $args['image_size'],
		'src' => $args['src'],
	] );

	echo '<div class="content-wrap">' .
			'<h5 class="nebotheme-featured-image__title m-0">' . esc_html( $args['label'] ) . '</h5>' .
		'</div>' .
		'</a>' .
	'</div>';
}

/**
 * Echoes slider
 *
 * @param array $slides
 * @param callable $callback
 * @param array $options
 *
 * @return void
 */
function nebotheme_render_slider( array $slides, callable $callback, array $options = [] ) {
	$attrs_main = [
		'class' => 'nebotheme-slider__slick',
	];
	$attrs = [
		'class' => [ 'nebotheme-slider' ],
	];
	$options_def = [
		'slidesToShow' => 1,
	];
	$options = array_merge( $options_def, $options );

	if ( ! empty( $options ) ) {
		$attrs_main['data-slider-options'] = wp_json_encode( $options );
	}

	if ( ! empty( $options['slidesToShow'] ) ) {
		$attrs['style'] = "--columns-default: {$options['slidesToShow']}";
	}

	if ( 1 === (int) $options['slidesToShow'] ) {
		$attrs['class'][] = 'nebotheme-slider--single';
	}

	?>
	<div <?php nebotheme_render_attrs( $attrs ); ?>>
		<div class="nebotheme-slider__inner">
			<div <?php nebotheme_render_attrs( $attrs_main ); ?>>
				<?php
				foreach ( $slides as $slide ) {
					echo '<div class="nebotheme-slider__item">';

					call_user_func( $callback, $slide );

					echo '</div>';
				}
				?>
			</div>
			<?php if ( ! empty( $options['arrows'] ) ) : ?>
				<div class="nebotheme-slider__arrows"></div>
			<?php endif; ?>
		</div>
	</div>
	<?php
}

/**
 * Echoes post slider.
 *
 * @param \WP_Query $slider_query
 * @param callable $callback
 * @param array $options
 */
function nebotheme_render_post_slider( \WP_Query $slider_query, callable $callback, array $options = [] ) {
	if ( ! $slider_query->have_posts() ) {
		return;
	}

	WP_Query_Agent::loop_start();

	nebotheme_render_slider(
		$slider_query->posts,
		function() use ( $slider_query, $callback ) {
			if ( ! $slider_query->have_posts() ) {
				return;
			}

			$slider_query->the_post();

			call_user_func( $callback );
		},
		$options
	);

	WP_Query_Agent::loop_end();
}

/**
 * Echoes popup
 *
 * @param string $name
 * @param callable $callback
 * @param array $options
 *
 * @return void
 */
function nebotheme_render_popup( $name, callable $callback, array $options = [] ) {
	$options_def = [
		'trigger' => false,
	];
	$options = array_merge( $options_def, $options );
	$options_allow_frontend = [];
	$options_frontend = [];
	$event_trigger = "popup:{$name}:hide";

	foreach ( $options as $option_name => $option_value ) {
		if ( ! in_array( $option_name, $options_allow_frontend, true ) ) {
			continue;
		}

		$options_frontend[ $option_name ] = $option_value;
	}

	$attrs = [
		'id' => "nebotheme-popup-{$name}",
		'class' => 'nebotheme-popup',
		'data-name' => $name,
	];

	if ( $options_frontend ) {
		$attrs['data-options'] = wp_json_encode( $options_frontend );
	}

	?>
	<div <?php nebotheme_render_attrs( $attrs ); ?>>
		<div class="nebotheme-popup__outer">
			<div class="grid-container">
				<div class="nebotheme-popup__inner nebotheme-scroll-padding">
					<?php call_user_func( $callback ); ?>
				</div>
				<?php
				if ( $options['trigger'] ) {
					nebotheme_render_trigger_close( $event_trigger );
				}
				?>
			</div>
		</div>
		<?php nebotheme_render_trigger( $event_trigger, 'nebotheme-popup__overlay' ); ?>
	</div>
	<?php
}

/**
 * Echoes embed video via shortcode
 *
 * @param string $video_url Youtube, vimeo etc.
 * @param array $attrs HTML attributes.
 *
 * @return void
 */
function nebotheme_render_embed( $video_url, array $attrs = [] ) {
	global $wp_embed;

	if ( ! $video_url ) {
		return;
	}

	echo '<div class="nebotheme-embed-shortcode">' .
		do_shortcode(
			$wp_embed->run_shortcode(
				'[embed ' . nebotheme_get_render_attrs( $attrs ) . ']' . esc_url( $video_url ) . '[/embed]'
			)
		) .
	'</div>';
}

/**
 * Echoes image
 *
 * @return void
 */
function nebotheme_render_attachment( array $args = [] ) {
	static $args_default = [];

	if ( empty( $args_default ) ) {
		$args_default = [
			'id' => '',
			'size' => 'full',

			'src' => '',
			'alt' => get_bloginfo( 'description' ),
			'title' => null,

			'lazyload' => true,
		];
	}

	$args = array_merge( $args_default, $args );

	$is_valid_id = (
		! empty( $args['id'] ) &&
		wp_attachment_is_image( $args['id'] ) &&
		'publish' === get_post_status( $args['id'] )
	);

	$is_valid_src = ! empty( $args['src'] );

	if ( ! $is_valid_id && ! $is_valid_src ) {
		return;
	}

	if ( $args['lazyload'] && ! nebotheme_is_custom_lazyload() ) {
		if ( $args_default['lazyload'] ) {
			$args_default['lazyload'] = false;
		}

		$args['lazyload'] = false;
	}

	echo '<span class="nebotheme-image">' .
	'<span class="nebotheme-image__inner">';

	if ( $is_valid_id ) {
		echo wp_get_attachment_image( $args['id'], $args['size'] );
	} elseif ( $is_valid_src ) {
		$attrs = [
			'src' => $args['src'],
			'alt' => $args['alt'],
			'title' => $args['title'],
		];

		echo '<img ' . nebotheme_get_render_attrs( $attrs ) . '>';
	}

	if ( $args['lazyload'] && $is_valid_id ) {
		Lazy_Load::render_animation();
	}

	echo '</span></span>';
}
