<?php
/**
 * Template Functions for general elements.
 *
 * Functions components.
 *
 * @package Yaffo
 */

use NeboTheme\Yaffo\Admin\Meta_Boxes;
use NeboTheme\Yaffo\Sidebars\Sidebar_Manager;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Echoes Post Header
 */
function nebotheme_render_post_single_header() {
	if (
		! is_singular( 'post' ) ||
		! Meta_Boxes::get_pm_safe( 'post_header_show' )
	) {
		return;
	}

	echo '<div class="nebotheme-post-single__header">' .
	'<div class="nebotheme-post-single__header-inner">';

	nebotheme_render_post_meta(
		[
			'category',
		]
	);

	nebotheme_render_post_title(
		[
			'href' => false,
			'tag' => nebotheme_get_tag_h1(),
		]
	);

	nebotheme_render_post_meta( nebotheme_get_tm( 'homepage_meta_data_single' ) );

	echo '</div>' .
	'</div>';
}

/**
 * Outputs a single comment.
 *
 * @param \WP_Comment $comment Comment to display.
 * @param array $args An array of arguments.
 * @param int $depth Depth of the current comment.
 */
function nebotheme_comments_callback( \WP_Comment $comment, array $args, $depth ) {
	?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
		<div id="comment-<?php comment_ID(); ?>" class="comment-body">
			<div class="comment-body-left">
				<figure class="comment-author-avatar vcard">
					<a href="<?php echo esc_url( get_comment_author_url( $comment ) ); ?>">
						<?php echo get_avatar( $comment->comment_author_email, 60, get_option( 'avatar_default' ) ); ?>
					</a>
				</figure>
				<?php edit_comment_link( esc_attr__( 'Edit', 'yaffo' ), '', '' ); ?>
			</div>
			<div class="comment-body-right">
				<h4 class="comment-nebotheme">
					<?php
					printf(
						'<span class="fn">%s</span>',
						get_comment_author_link( $comment )
					);
					?>
					</h4>
				<div class="comment-meta">
					<div class="comment-meta-date-time">
						<span class="date">
							<?php echo esc_html( get_comment_date() ); ?>
						</span>
						<span class="time">
							<?php echo esc_html( get_comment_time() ); ?>
						</span>
					</div>
				</div>
				<div class="comment-content">
					<?php
					comment_text();

					if ( '0' === $comment->comment_approved ) {
						?>
						<p>
							<em><?php esc_html_e( 'Your comment is awaiting moderation.', 'yaffo' ); ?></em>
						</p>
						<?php
					}

					comment_reply_link(
						array_merge(
							$args,
							[
								'depth' => $depth,
								'max_depth' => $args['max_depth'],
								'reply_text' => esc_attr__( 'Reply', 'yaffo' ),
							]
						)
					);
	?>
				</div>
			</div>
		</div>
	</li>
	<?php
}

/**
 * Echoes comments pagination.
 */
function nebotheme_render_comments_pagination() {
	$previous_comments_link = get_previous_comments_link();
	$next_comments_link = get_next_comments_link();

	if ( ! $previous_comments_link && ! $next_comments_link ) {
		return;
	}

	?>
	<aside class="nebotheme-comments__pagination">
		<?php if ( $previous_comments_link ) : ?>
			<div class="nebotheme-comments__pagination__item prev">
				<?php previous_comments_link( esc_html__( 'Older Comments', 'yaffo' ) ); ?>
			</div>
		<?php endif; ?>
		<?php if ( $next_comments_link ) : ?>
			<div class="nebotheme-comments__pagination__item next">
				<?php next_comments_link( esc_html__( 'Newer Comments', 'yaffo' ) ); ?>
			</div>
		<?php endif; ?>
	</aside>
	<?php
}

/**
 * Echoes Off-Canvas.
 */
function nebotheme_render_off_canvas() {
	get_template_part( 'template-parts/off-canvas' );
}

add_action( 'nebotheme_render_body_end', 'nebotheme_render_off_canvas' );

/**
 * Echoes templates in wp-footer.
 */
function nebotheme_render_search_popup() {
	nebotheme_render_popup(
		'search',
		function() {
			echo '<div class="nebotheme-search-popup">';

			nebotheme_render_search_form(
				[
					'placeholder' => esc_html__( 'Enter Keywords', 'yaffo' ),
				]
			);

			nebotheme_render_trigger_close( 'popup:search:hide' );

			echo '</div>';
		}
	);
}

add_action( 'nebotheme_render_body_end', 'nebotheme_render_search_popup' );

/**
 * Get render search form.
 *
 * @param array $args
 */
function nebotheme_get_render_search_form( array $args = [] ) {
	ob_start();

	nebotheme_render_search_form( $args );

	return ob_get_clean();
}

add_filter( 'get_search_form', 'nebotheme_get_render_search_form', 10, 0 );

/**
 * Echoes search form.
 *
 * @param array $args
 */
function nebotheme_render_search_form( array $args = [] ) {
	$args_default = [
		'button_icon' => 'nebotheme-icon-custom-search',
		'button_text' => '',
		'placeholder' => esc_attr__( 'Search for...', 'yaffo' ),
	];

	$args = array_merge( $args_default, $args );

	ob_start();
	?>
	<div class="nebotheme-search">
		<?php do_action( 'nebotheme_render_search_form_start' ); ?>
		<form role="search" method="get" action="<?php echo esc_url( home_url( '/' ) ); ?>" autocomplete="off">
			<div class="nebotheme-search__inner">
				<div class="nebotheme-search__item search-field-wrap">
					<input type="search" name="s" title="<?php echo esc_attr( $args['placeholder'] ); ?>"  placeholder="<?php echo esc_attr( $args['placeholder'] ); ?>" value="<?php echo get_search_query(); ?>" class="search-field" required/>
				</div>
				<div class="nebotheme-search__item search-submit-wrap">
					<button type="submit" title="<?php esc_attr_e( 'Search', 'yaffo' ); ?>" class="search-submit nebotheme-icon-margin <?php echo esc_attr( $args['button_icon'] ); ?>" >
						<?php echo esc_html( $args['button_text'] ); ?>
					</button>
				</div>
			</div>
		</form>
		<?php do_action( 'nebotheme_render_search_form_end' ); ?>
	</div>
	<?php
}

/**
 * Echoes select component.
 *
 * @param array $attrs
 * @param array $options
 * @param mixed $value
 */
function nebotheme_render_select( array $attrs = [], array $options = [], $value = null ) {
	echo '<select ' . nebotheme_get_render_attrs( $attrs ) . '>';

	foreach ( $options as $option => $label ) {
		echo '<option value="' . esc_attr( $option ) . '"' . nebotheme_get_render_selected( $value, $option, false ) . '>' .
			esc_html( $label ) .
		'</option>';
	}

	echo '</select>';
}

/**
 * Custom arrows for wp calendar.
 */
function nebotheme_filter_wp_calendar( $calendar_output ) {
	if ( Sidebar_Manager::is_rendering_sidebar() ) {
		$calendar_output = preg_replace( '/&laquo;|&raquo;/', '', $calendar_output );
	}

	return $calendar_output;
}

add_filter( 'get_calendar', 'nebotheme_filter_wp_calendar' );

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function nebotheme_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="' . esc_url( get_bloginfo( 'pingback_url' ) ) . '">';
	}
}

add_action( 'wp_head', 'nebotheme_pingback_header' );

/**
 * Get render html separator for breadcrumb.
 */
function nebotheme_get_render_breadcrumbs_separator() {
	return '<span class="nebotheme-breadcrumbs-separator"></span>';
}

/**
 * Render variable block
 */
function nebotheme_render_var_block_start() {
	$attrs = [
		'class' => [ 'nebotheme-var-block' ] + apply_filters( 'nebotheme_var_block_class', [] ),
	];

	if ( is_singular() ) {
		$post = get_post();

		if ( $post ) {
			$attrs['data-id'] = $post->ID;
		}
	}

	?>
	<div <?php nebotheme_render_attrs( $attrs ); ?>>
		<?php do_action( 'nebotheme_render_var_block_start' ); ?>
		<div class="grid-container">
			<div class="site-content">
	<?php
}

/**
 * Render variable block
 */
function nebotheme_render_var_block_end() {
	?>
		</div><!-- .site-content -->
			<?php Sidebar_Manager::render(); ?>
		</div><!-- .grid-container -->
		<?php do_action( 'nebotheme_render_var_block_end' ); ?>
	</div><!-- .nebotheme-var-block -->
	<?php
	do_action( 'nebotheme_render_var_block_after' );
}
