<?php
/**
 * Theme Functions.
 *
 * @package Yaffo
 */

use NeboTheme\Yaffo\Admin\Meta_Boxes;
use NeboTheme\Yaffo\Homepage;

/**
 * Get Fields for Meta Boxes
 */
function nebotheme_get_meta_boxes_fields( $fields ) {
	$post_type = get_post_type();

	$fields = array_merge( $fields, [
		/* < Gallery */
		'gallery_images' => [
			'label' => esc_html__( 'Gallery Images', 'yaffo' ),
			'type' => Meta_Boxes::CONTROL_IMAGE,
			'multiple' => true,
			'tab' => 'gallery',
		],
		/* > Gallery */

		/* < Video */
		'video_url' => [
			'label' => esc_html__( 'Embedded Video Link', 'yaffo' ),
			'description' => '<a target="_blank" href="https://wordpress.org/support/article/embeds/#okay-so-what-sites-can-i-embed-from">' . esc_html__( 'What sites can i embed video from?', 'yaffo' ) . '</a>',
			'placeholder' => esc_html__( 'Enter URL', 'yaffo' ),
			'type' => Meta_Boxes::CONTROL_TEXT,
			'tab' => 'video',
			'size' => 45,
		],
		/* > Video */

		/* < Layout */
		'post_header_show' => [
			'label' => esc_html__( 'Display Post Header', 'yaffo' ),
			'type' => Meta_Boxes::CONTROL_SWITCHER,
			'default' => YAFFO_VALUE_POSITIVE,
			'label_enable' => esc_html__( 'Yes', 'yaffo' ),
			'label_disabled' => esc_html__( 'No', 'yaffo' ),
			'tab' => 'layout',
			'condition' => [
				'_post_type' => 'post',
			],
		],
		'featured_image_show' => [
			'label' => esc_html__( 'Display Featured Image', 'yaffo' ),
			'type' => Meta_Boxes::CONTROL_SWITCHER,
			'default' => YAFFO_VALUE_POSITIVE,
			'label_enable' => esc_html__( 'Yes', 'yaffo' ),
			'label_disabled' => esc_html__( 'No', 'yaffo' ),
			'tab' => 'layout',
			'condition' => [
				'_post_type' => 'post',
			],
		],
		'headline_show' => [
			'label' => esc_html__( 'Headline', 'yaffo' ),
			'type' => Meta_Boxes::CONTROL_SWITCHER,
			'default' => YAFFO_VALUE_POSITIVE,
			'tab' => 'layout',
			'condition' => [
				'_post_type' => 'page',
			],
		],
		/* > Layout */

		/* < Video Background */
		'video_bg' => [
			'label' => esc_html__( 'Display Video Background', 'yaffo' ),
			'type' => Meta_Boxes::CONTROL_SWITCHER,
			'default' => YAFFO_VALUE_NEGATIVE,
			'label_enable' => esc_html__( 'Yes', 'yaffo' ),
			'label_disabled' => esc_html__( 'No', 'yaffo' ),
			'tab' => 'video_bg',
			'condition' => [
				'_post_type' => 'post',
			],
		],
		'video_bg_youtube_url' => [
			'label' => esc_html__( 'YouTube URL', 'yaffo' ),
			'placeholder' => esc_html__( 'Enter URL', 'yaffo' ),
			'type' => Meta_Boxes::CONTROL_TEXT,
			'tab' => 'video_bg',
			'size' => 45,
			'condition' => [
				'_post_type' => 'post',
				'video_bg!' => YAFFO_VALUE_NEGATIVE,
			],
		],
		'video_bg_location' => [
			'label' => esc_html__( 'Locations', 'yaffo' ),
			'type' => Meta_Boxes::CONTROL_SELECT,
			'placeholder' => esc_html__( 'Choose Locations', 'yaffo' ),
			'multiple' => true,
			'options' => [
				'archive/search' => esc_html__( 'Archive/Search Blog', 'yaffo' ),
				'page/home' => esc_html__( 'Page/Homepage Blog', 'yaffo' ),
				'page/home:slider' => esc_html__( 'Page/Homepage Slider', 'yaffo' ),
				'single' => esc_html__( 'Single Post', 'yaffo' ),
			],
			'tab' => 'video_bg',
			'condition' => [
				'_post_type' => 'post',
				'video_bg!' => YAFFO_VALUE_NEGATIVE,
				'video_bg_youtube_url!' => '',
			],
		],
		'video_bg_start' => [
			'label' => esc_html__( 'Start Time (sec)', 'yaffo' ),
			'type' => Meta_Boxes::CONTROL_NUMBER,
			'placeholder' => 0,
			'size_em' => 5,
			'tab' => 'video_bg',
			'condition' => [
				'_post_type' => 'post',
				'video_bg!' => YAFFO_VALUE_NEGATIVE,
				'video_bg_youtube_url!' => '',
				'video_bg_location!' => '',
			],
		],
		'video_bg_end' => [
			'label' => esc_html__( 'End Time (sec)', 'yaffo' ),
			'type' => Meta_Boxes::CONTROL_NUMBER,
			'default' => 20,
			'placeholder' => 20,
			'size_em' => 5,
			'tab' => 'video_bg',
			'condition' => [
				'_post_type' => 'post',
				'video_bg!' => YAFFO_VALUE_NEGATIVE,
				'video_bg_youtube_url!' => '',
				'video_bg_location!' => '',
			],
		],
		/* > Video Background */

		/* < Hidden */
		'_post_type' => [
			'type' => Meta_Boxes::CONTROL_HIDDEN,
			'default' => $post_type,
			'tab' => '_hidden',
		],
		/* > Hidden */
	] );

	return $fields;
}

add_filter( 'nebotheme_meta_boxes_fields', 'nebotheme_get_meta_boxes_fields' );

/**
 * Get Tabs for Meta Boxes
 */
function nebotheme_get_meta_boxes_tabs( $tabs ) {
	$tabs = array_merge( $tabs, [
		'layout' => [
			'label' => esc_html__( 'Layout', 'yaffo' ),
		],
		/* < Posts */
		'gallery' => [
			'label' => esc_html__( 'Gallery Format', 'yaffo' ),
			'post_type' => [ 'post' ],
		],
		'video' => [
			'label' => esc_html__( 'Video Format', 'yaffo' ),
			'post_type' => [ 'post' ],
		],
		'video_bg' => [
			'label' => esc_html__( 'Video Background', 'yaffo' ),
			'post_type' => [ 'post' ],
		],
		/* Posts > */
		'_hidden' => [
			'label' => esc_html__( 'Hidden', 'yaffo' ),
		],
	] );

	return $tabs;
}

add_filter( 'nebotheme_meta_boxes_tabs', 'nebotheme_get_meta_boxes_tabs' );

/**
 * Get Theme Vars.
 */
function nebotheme_get_theme_vars_default( array $theme_vars ) {
	global $content_width;

	$theme_vars = array_merge( $theme_vars, [
		'logo_urls' => [
			'custom_logo' => YAFFO_URI_IMAGES . '/logos/header/logo.png',
			'custom_logo_retina' => YAFFO_URI_IMAGES . '/logos/header/logo@2x.png',

			'logo_header_mobile' => YAFFO_URI_IMAGES . '/logos/header-mobile/logo.png',
			'logo_header_mobile_retina' => YAFFO_URI_IMAGES . '/logos/header-mobile/logo@2x.png',

			'logo_off_canvas' => YAFFO_URI_IMAGES . '/logos/off-canvas/logo.png',
			'logo_off_canvas_retina' => YAFFO_URI_IMAGES . '/logos/off-canvas/logo@2x.png',

			'logo_footer' => YAFFO_URI_IMAGES . '/logos/footer/logo.png',
			'logo_footer_retina' => YAFFO_URI_IMAGES . '/logos/footer/logo@2x.png',
		],
		'post_types_support' => [
			'post',
			'page',
		],
		'color' => [
			'primary' => [
				'content' => esc_html__( 'Content', 'yaffo' ),
				'primary' => esc_html__( 'Primary', 'yaffo' ),
				'secondary' => esc_html__( 'Secondary', 'yaffo' ),
				'hover' => esc_html__( 'Highlight', 'yaffo' ),
				'headings' => esc_html__( 'Headings', 'yaffo' ),
				'bg' => esc_html__( 'Background', 'yaffo' ),
				'alt' => esc_html__( 'Alternate', 'yaffo' ),
				'border' => esc_html__( 'Border', 'yaffo' ),
			],
			'header_sticky' => [
				'element' => esc_html__( 'Element', 'yaffo' ),
				'element_hover' => esc_html__( 'On Hover', 'yaffo' ),
				'bg_color' => esc_html__( 'Background Color', 'yaffo' ),
				'bd' => esc_html__( 'Border Color', 'yaffo' ),
			],
			'header_top' => [
				'element' => esc_html__( 'Element', 'yaffo' ),
				'element_hover' => esc_html__( 'On Hover', 'yaffo' ),
				'bg_color' => esc_html__( 'Background Color', 'yaffo' ),
				'bd' => esc_html__( 'Border Color', 'yaffo' ),
			],
			'header_main' => [
				'element' => esc_html__( 'Color', 'yaffo' ),
				'element_hover' => esc_html__( 'Color On Hover', 'yaffo' ),
				'bg_color' => esc_html__( 'Background Color', 'yaffo' ),
				'bd' => esc_html__( 'Border Color', 'yaffo' ),
			],
			'menu' => [
				'element' => esc_html__( 'Normal', 'yaffo' ),
				'element_hover' => esc_html__( 'On Hover', 'yaffo' ),
				'element_active' => esc_html__( 'On Current Page', 'yaffo' ),
			],
			'menu_dropdown' => [
				'element' => esc_html__( 'Normal', 'yaffo' ),
				'element_hover' => esc_html__( 'On Hover', 'yaffo' ),
				'element_active' => esc_html__( 'On Current Page', 'yaffo' ),
				'bg' => esc_html__( 'Background Color', 'yaffo' ),
				'bd' => esc_html__( 'Border Color', 'yaffo' ),
			],
			'off_canvas' => [
				'content' => esc_html__( 'Content', 'yaffo' ),
				'primary' => esc_html__( 'Primary', 'yaffo' ),
				'secondary' => esc_html__( 'Secondary', 'yaffo' ),
				'hover' => esc_html__( 'Highlight', 'yaffo' ),
				'headings' => esc_html__( 'Headings', 'yaffo' ),
				'bg' => esc_html__( 'Background', 'yaffo' ),
				'alt' => esc_html__( 'Alternate', 'yaffo' ),
				'border' => esc_html__( 'Border', 'yaffo' ),
			],
			'off_canvas_menu' => [
				'element' => esc_html__( 'Normal', 'yaffo' ),
				'element_hover' => esc_html__( 'On Hover', 'yaffo' ),
				'element_active' => esc_html__( 'On Current Page', 'yaffo' ),
			],
		],
		'social_links' => [
			'behance',
			'dribbble',
			'email',
			'facebook',
			'flickr',
			'github',
			'goodreads',
			'instagram',
			'linkedin',
			'medium',
			'pinterest',
			'reddit',
			'rss',
			'snapchat',
			'soundcloud',
			'spotify',
			'telegram',
			'tumblr',
			'twitch',
			'twitter',
			'tiktok',
			'vimeo',
			'vk',
			'website',
			'youtube',
			'giphy',
		],
		'socials_data' => [
			'behance' => [
				'label' => esc_html__( 'Behance', 'yaffo' ),
				'label_admin' => esc_html__( 'URL', 'yaffo' ),
				'placeholder' => 'https://behance.net',
				'icon' => 'nebotheme-icon-behance',
			],
			'dribbble' => [
				'label' => esc_html__( 'Dribbble', 'yaffo' ),
				'label_admin' => esc_html__( 'URL', 'yaffo' ),
				'placeholder' => 'https://dribbble.com',
				'icon' => 'nebotheme-icon-dribbble-circled',
			],
			'email' => [
				'label' => esc_html__( 'Email', 'yaffo' ),
				'user_skip' => true,
				'url' => get_bloginfo( 'admin_email' ),
				'placeholder' => 'example@example.com',
				'icon' => 'nebotheme-icon-mail-alt',
			],
			'facebook' => [
				'label' => esc_html__( 'Facebook', 'yaffo' ),
				'label_admin' => esc_html__( 'URL', 'yaffo' ),
				'placeholder' => 'https://facebook.com',
				'icon' => 'nebotheme-icon-facebook',
			],
			'flickr' => [
				'label' => esc_html__( 'Flickr', 'yaffo' ),
				'label_admin' => esc_html__( 'URL', 'yaffo' ),
				'placeholder' => 'https://www.flickr.com',
				'icon' => 'nebotheme-icon-flickr',
			],
			'github' => [
				'label' => esc_html__( 'GitHub', 'yaffo' ),
				'label_admin' => esc_html__( 'URL', 'yaffo' ),
				'placeholder' => 'https://github.com',
				'icon' => 'nebotheme-icon-github-circled',
			],
			'goodreads' => [
				'label' => esc_html__( 'Goodreads', 'yaffo' ),
				'label_admin' => esc_html__( 'URL', 'yaffo' ),
				'placeholder' => 'https://www.goodreads.com',
				'icon' => 'nebotheme-icon-goodreads',
			],
			'instagram' => [
				'label' => esc_html__( 'Instagram', 'yaffo' ),
				'label_admin' => esc_html__( 'URL', 'yaffo' ),
				'url_default' => 'https://www.instagram.com/nebo.theme',
				'placeholder' => 'https:///www.instagram.com/',
				'icon' => 'nebotheme-icon-custom-instagram',
			],
			'linkedin' => [
				'label' => esc_html__( 'LinkedIn', 'yaffo' ),
				'label_admin' => esc_html__( 'URL', 'yaffo' ),
				'placeholder' => 'https://linkedin.com',
				'icon' => 'nebotheme-icon-linkedin',
			],
			'medium' => [
				'label' => esc_html__( 'Medium', 'yaffo' ),
				'label_admin' => esc_html__( 'URL', 'yaffo' ),
				'placeholder' => 'https://medium.com',
				'icon' => 'nebotheme-icon-medium',
			],
			'pinterest' => [
				'label' => esc_html__( 'Pinterest', 'yaffo' ),
				'label_admin' => esc_html__( 'URL', 'yaffo' ),
				'placeholder' => 'https://pinterest.com',
				'icon' => 'nebotheme-icon-pinterest-circled',
			],
			'reddit' => [
				'label' => esc_html__( 'Reddit', 'yaffo' ),
				'label_admin' => esc_html__( 'URL', 'yaffo' ),
				'placeholder' => 'https://reddit.com',
				'icon' => 'nebotheme-icon-reddit',
			],
			'rss' => [
				'label' => esc_html__( 'RSS Feed', 'yaffo' ),
				'placeholder' => get_bloginfo( 'rss_url' ),
				'label_admin' => esc_html__( 'URL', 'yaffo' ),
				'icon' => 'nebotheme-icon-rss',
			],
			'snapchat' => [
				'label' => esc_html__( 'Snapchat', 'yaffo' ),
				'label_admin' => esc_html__( 'URL', 'yaffo' ),
				'placeholder' => 'https://snapchat.com',
				'icon' => 'nebotheme-icon-snapchat',
			],
			'soundcloud' => [
				'label' => esc_html__( 'SoundCloud', 'yaffo' ),
				'label_admin' => esc_html__( 'URL', 'yaffo' ),
				'placeholder' => 'https://soundcloud.com',
				'icon' => 'nebotheme-icon-soundcloud',
			],
			'spotify' => [
				'label' => esc_html__( 'Spotify', 'yaffo' ),
				'label_admin' => esc_html__( 'URL', 'yaffo' ),
				'placeholder' => 'https://spotify.com',
				'icon' => 'nebotheme-icon-spotify',
			],
			'stumbleupon' => [
				'label' => esc_html__( 'Stumbleupon', 'yaffo' ),
				'placeholder' => 'https://stumbleupon.com',
				'icon' => 'nebotheme-icon-stumbleupon',
			],
			'telegram' => [
				'label' => esc_html__( 'Telegram', 'yaffo' ),
				'label_admin' => esc_html__( 'Channel & User URL', 'yaffo' ),
				'placeholder' => 'https://t.me',
				'icon' => 'nebotheme-icon-telegram',
			],
			'tumblr' => [
				'label' => esc_html__( 'Tumblr', 'yaffo' ),
				'label_admin' => esc_html__( 'URL', 'yaffo' ),
				'placeholder' => 'https://tumblr.com',
				'icon' => 'nebotheme-icon-tumblr',
			],
			'twitch' => [
				'label' => esc_html__( 'Twitch', 'yaffo' ),
				'label_admin' => esc_html__( 'URL', 'yaffo' ),
				'placeholder' => 'https://twitch.com',
				'icon' => 'nebotheme-icon-twitch',
			],
			'twitter' => [
				'label_admin' => esc_html__( 'URL', 'yaffo' ),
				'label' => esc_html__( 'Twitter', 'yaffo' ),
				'username_default' => 'envato',
				'placeholder' => 'https://twitter.com',
				'icon' => 'nebotheme-icon-twitter',
			],
			'tiktok'      => [
				'label_admin'      => esc_html__( 'URL', 'yaffo' ),
				'label'            => esc_html__( 'TikTok', 'yaffo' ),
				'username_default' => 'tiktok',
				'placeholder'      => 'https://www.tiktok.com/',
				'icon'             => 'nebotheme-icon-custom-tiktok',
			],
			'vk' => [
				'label' => esc_html__( 'VK', 'yaffo' ),
				'label_admin' => esc_html__( 'URL', 'yaffo' ),
				'placeholder' => 'https://vk.com',
				'icon' => 'nebotheme-icon-vkontakte',
			],
			'vimeo' => [
				'label' => esc_html__( 'Vimeo', 'yaffo' ),
				'label_admin' => esc_html__( 'URL', 'yaffo' ),
				'placeholder' => 'https://vimeo.com',
				'icon' => 'nebotheme-icon-vimeo',
			],
			'youtube' => [
				'label' => esc_html__( 'YouTube', 'yaffo' ),
				'label_admin' => esc_html__( 'URL', 'yaffo' ),
				'placeholder' => 'https://youtube.com',
				'icon' => 'nebotheme-icon-youtube-play',
			],
			'whatsapp' => [
				'label' => esc_html__( 'Whatsapp', 'yaffo' ),
				'placeholder' => 'https://whatsapp.com',
				'icon' => 'nebotheme-icon-whatsapp',
			],
			'website' => [
				'label' => esc_html__( 'Website', 'yaffo' ),
				'user_skip' => true,
				'placeholder' => 'https://website.com',
				'icon' => 'nebotheme-icon-globe',
			],
			'giphy' => [
				'label' => esc_html__( 'Giphy', 'yaffo' ),
				'user_skip' => true,
				'placeholder' => 'https://giphy.com/',
				'icon' => '',
				'svg' => '<svg height="2500" width="2500" xmlns="http://www.w3.org/2000/svg" viewBox="4 2 16.32 20"><g fill="none" fill-rule="evenodd"><path d="M6.331 4.286H17.99v15.428H6.33z" fill="#000"/><g fill-rule="nonzero"><path d="M4 3.714h2.331v16.572H4z" fill="#04ff8e"/><path d="M17.989 8.286h2.331v12h-2.331z" fill="#8e2eff"/><path d="M4 19.714h16.32V22H4z" fill="#00c5ff"/><path d="M4 2h9.326v2.286H4z" fill="#fff152"/><path d="M17.989 6.571V4.286h-2.332V2h-2.331v6.857h6.994V6.571" fill="#ff5b5b"/><path d="M17.989 11.143V8.857h2.331" fill="#551c99"/></g><path d="M13.326 2v2.286h-2.332" fill="#999131"/></g></svg>',
			],
		],
		'image_sizes' => [
			'yaffo-small-square' => [
				'label' => esc_html__( 'Yaffo Small Square', 'yaffo' ),
				'width' => 90,
				'height' => 90,
				'crop' => true,
			],
			'yaffo-grid' => [
				'label' => esc_html__( 'Yaffo Grid', 'yaffo' ),
				'width' => 580,
				'height' => 420,
				'crop' => true,
			],
			'yaffo-square' => [
				'label' => esc_html__( 'Yaffo Square', 'yaffo' ),
				'width' => 580,
				'height' => 580,
				'crop' => true,
			],
			'yaffo-medium' => [
				'label' => esc_html__( 'Yaffo Medium', 'yaffo' ),
				'width' => 830,
				'height' => 9999,
				'crop' => false,
			],
			'yaffo-content-width' => [
				'label' => esc_html__( 'Yaffo Content Width', 'yaffo' ),
				'width' => $content_width,
				'height' => 9999,
				'crop' => false,
			],
		],
	] );

	return $theme_vars;
}

add_filter( 'nebotheme_default_theme_vars', 'nebotheme_get_theme_vars_default' );


/**
 * Get Default Theme Mods.
 */
function nebotheme_get_default_theme_mods( array $theme_mods ) {
	$theme_mods = array_merge( $theme_mods, [
		'social_icons_sortable' => [
			'facebook',
			'twitter',
			'instagram',
			'youtube',
		],
		'footer_copyright' => esc_html__( 'Lifestyle Blog &amp; Magazine WordPress Theme', 'yaffo' ),
	] );

	return $theme_mods;
}

add_filter( 'nebotheme_default_theme_mods', 'nebotheme_get_default_theme_mods' );

/**
 * Check if header divider need.
 */
function nebotheme_is_active_header_divider() {
	$is_active = true;

	return apply_filters( 'nebotheme_is_active_header_divider', $is_active );
}

/**
 * Filter for body classes.
 */
function nebotheme_body_class( array $body_classes ) {
	if ( nebotheme_is_active_header_divider() ) {
		$body_classes[] = 'nebotheme-header--divider';
	}

	return $body_classes;
}

add_filter( 'body_class', 'nebotheme_body_class' );

/**
 * Filter for excerpt more
 */
function nebotheme_excerpt_more() {
	return ' &hellip;';
};

add_filter( 'excerpt_more', 'nebotheme_excerpt_more' );

/**
 * Sanitizes content for allowed HTML tags for text.
 *
 * @param string $data Post content to filter.
 * @return string Filtered post content with allowed HTML tags and attributes intact.
 */
function nebotheme_get_kses_content( $data ) {
	return wp_kses( $data, 'nebotheme_get_kses_content' );
}

/**
 * Filters and Returns a list of allowed tags and attributes for a given context.
 *
 * @param array  $allowedposttags Array of allowed tags.
 * @param string $context Context type (explicit).
 *
 * @return array
 */
function nebotheme_kses_allowed_html( $allowedposttags, $context ) {
	if ( 'nebotheme_get_kses_content' === $context ) {
		$allowedposttags = [
			'h1' => [
				'id' => [],
				'class' => [],
				'title' => [],
				'align' => [],
			],
			'h2' => [
				'id' => [],
				'class' => [],
				'title' => [],
				'align' => [],
			],
			'h3' => [
				'id' => [],
				'class' => [],
				'title' => [],
				'align' => [],
			],
			'h4' => [
				'id' => [],
				'class' => [],
				'title' => [],
				'align' => [],
			],
			'h5' => [
				'id' => [],
				'class' => [],
				'title' => [],
				'align' => [],
			],
			'h6' => [
				'id' => [],
				'class' => [],
				'title' => [],
				'align' => [],
			],
			'p' => [
				'id' => [],
				'class' => [],
				'title' => [],
				'align' => [],
			],
			'span' => [
				'id' => [],
				'class' => [],
				'title' => [],
			],
			'div' => [
				'id' => [],
				'class' => [],
				'title' => [],
				'align' => [],
			],
			'a' => [
				'id' => [],
				'class' => [],
				'title' => [],
				'href' => [],
				'target' => [],
			],
			'b' => [
				'id' => [],
				'class' => [],
				'title' => [],
			],
			'i' => [
				'id' => [],
				'class' => [],
				'title' => [],
			],
			'em' => [
				'id' => [],
				'class' => [],
				'title' => [],
			],
			'strong' => [
				'id' => [],
				'class' => [],
				'title' => [],
			],
			'img' => [
				'id' => [],
				'class' => [],
				'src' => [],
				'width' => [],
				'height' => [],
				'alt' => [],
			],
			'br' => [ 'clear' => [] ],
			'svg' => [
				'height' => [],
				'width' => [],
				'xmlns' => [],
				'viewbox' => [],
			],
			'g' => [
				'fill' => [],
				'fill-rule' => [],
			],
			'path' => [
				'd' => [],
				'fill' => [],
				'fill-rule' => [],
			],
		];
	}

	return $allowedposttags;
}

add_filter( 'wp_kses_allowed_html', 'nebotheme_kses_allowed_html', 10, 2 );

/**
 * Check if post images has cropping.
 *
 * @return bool
 */
function nebotheme_is_image_cropped() {
	if ( is_archive() ) {
		return 'cropped' === nebotheme_get_tm( 'archive_image_cropped' );
	} elseif ( is_search() ) {
		return 'cropped' === nebotheme_get_tm( 'search_image_cropped' );
	} elseif ( is_home() || is_page() ) {
		return 'cropped' === Homepage::get_settings( 'homepage_image_cropped' );
	}

	return false;
}

/**
 * Excludes post meta.
 *
 * @return array
 */
function nebotheme_get_exclude_post_meta() {
	static $excludes = null;

	if ( is_null( $excludes ) ) {
		$excludes = [];

		if ( is_search() || is_archive() ) {
			if ( is_search() ) {
				$prefix_tm = 'search';
			} else {
				$prefix_tm = 'archive';
			}

			if ( ! nebotheme_get_tm( "{$prefix_tm}_blog_author" ) ) {
				$excludes[] = 'author';
			}

			if ( ! nebotheme_get_tm( "{$prefix_tm}_blog_date" ) ) {
				$excludes[] = 'date';
			}

			if ( ! nebotheme_get_tm( "{$prefix_tm}_blog_read_time" ) ) {
				$excludes[] = 'read_time';
			}
		} elseif ( Homepage::is_blog_enable() ) {
			if ( ! Homepage::get_settings( 'homepage_blog_author' ) ) {
				$excludes[] = 'author';
			}

			if ( ! Homepage::get_settings( 'homepage_blog_date' ) ) {
				$excludes[] = 'date';
			}

			if ( ! Homepage::get_settings( 'homepage_blog_read_time' ) ) {
				$excludes[] = 'read_time';
			}
		}
	}

	return $excludes;
}

add_action( 'wp', 'nebotheme_get_exclude_post_meta' );

/**
 * Get post author id.
 */
function nebotheme_get_author_id() {
	$post = get_post();

	if ( ! $post ) {
		return;
	}

	return get_the_author_meta( 'ID', $post->post_author );
}

/**
 * Echoes render author box
 */
function nebotheme_render_author_box() {
	if ( ! is_author() ) {
		return;
	}

	?>
	<div class="nebotheme-author-page">
		<div class="grid-container">
			<?php nebotheme_render_post_author_box(); ?>
		</div>
	</div>
	<?php
}

add_action( 'nebotheme_render_main_start', 'nebotheme_render_author_box' );
