<?php
/**
 * Module Ajax Search.
 *
 * @package Yaffo
 */

namespace NeboTheme\Yaffo\Modules\Ajax_Search;

use NeboTheme\Yaffo\Modules\Base_Module;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Module Ajax Search class.
 */
final class Module extends Base_Module {

	const NONCE_ACTION = 'nebotheme_ajax_search';

	/**
	 * {@inheritDoc}
	 */
	protected function add_hooks() {
		add_action( 'wp_ajax_nopriv_nebotheme_ajax_search', [ $this, 'ajax_search' ] );
		add_action( 'wp_ajax_nebotheme_ajax_search', [ $this, 'ajax_search' ] );
		add_action( 'nebotheme_render_search_form_end', [ $this, 'render' ] );
	}

	/**
	 * Echoes addition to search.
	 */
	public function render() {
		?>
		<div class="nebotheme-ajax-search">
			<div class="nebotheme-ajax-search__preloader"></div>
			<div class="nebotheme-ajax-search__list"></div>
		</div>
		<?php
	}

	/**
	 * {@inheritDoc}
	 */
	public function get_config_frontend() {
		return [
			'nonce' => wp_create_nonce( self::NONCE_ACTION ),
		];
	}

	/**
	 * Render search result on ajax.
	 */
	public function ajax_search() {
		if (
			! check_ajax_referer( self::NONCE_ACTION, false, false ) ||
			empty( $_REQUEST['q'] )
		) {
			wp_die( '', '', [ 'response' => 400 ] );
		}

		$text_query = sanitize_text_field( wp_unslash( $_REQUEST['q'] ) );

		$query_args = [
			'post_status' => 'publish',
			'posts_per_page' => 5,
			's' => $text_query,
		];

		$search_query = new \WP_Query( $query_args );

		$fn_title_hightlight = function( $text ) use ( $text_query ) {
			$text = preg_replace_callback( "/$text_query/iu", function( $match ) {
				return '<mark>' . $match[0] . '</mark>';
			}, $text );

			return $text;
		};

		if ( $search_query->have_posts() ) {
			add_filter( 'the_title', $fn_title_hightlight );

			while ( $search_query->have_posts() ) {
				$search_query->the_post();
				?>
				<div class="nebotheme-ajax-search__item">
					<div class="nebotheme-ajax-search__post">
						<?php
						nebotheme_render_thumbnail(
							[
								'size' => 'yaffo-small-square',
							]
						);

						nebotheme_render_post_title(
							[
								'tag' => 'h6',
							]
						);

						nebotheme_render_post_meta_post_type();
						?>
					</div>
				</div>
				<?php
			}

			add_filter( 'the_title', $fn_title_hightlight );
		}

		wp_die();
	}
}
