<?php
/**
 * Module Back To Top.
 *
 * @package Yaffo
 */

namespace NeboTheme\Yaffo\Modules\Back_To_Top;

use NeboTheme\Yaffo\Customize\Customize_Manager;
use NeboTheme\Yaffo\Modules\Base_Module;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Module Back To Top class.
 */
final class Module extends Base_Module {
	/**
	 * Add Hooks.
	 *
	 * Initialize module hooks.
	 *
	 * @return void.
	 */
	protected function add_hooks() {
		add_action( 'nebotheme_customize_fields', [ __CLASS__, 'customize_add_fields' ] );

		add_action( 'wp_body_open', [ __CLASS__, 'wp_body_open' ] );
	}

	/**
	 * Check if enable.
	 *
	 * @return bool
	 */
	public static function is_enabled() {
		return nebotheme_get_tm( 'back_to_top' );
	}

	/**
	 * Filter for body classes.
	 */
	public static function wp_body_open() {
		if ( ! static::is_enabled() ) {
			return;
		}

		echo '<a id="backToTop" href="#"><svg width="14" height="9" viewBox="0 0 14 9" fill="none" xmlns="http://www.w3.org/2000/svg"><path d="M1 8L7 2L13 8" stroke="white" stroke-width="1.5"/></svg></a>';
	}

	/**
	 * Add fields to customize.
	 */
	public static function customize_add_fields() {
		Customize_Manager::add_field(
			[
				'type'        => 'toggle',
				'settings'    => 'back_to_top',
				'label'       => esc_html__( 'Back To Top', 'yaffo' ),
				'section'     => 'miscellaneous',
				'default'     => false,
			]
		);
	}
}
