<?php
/**
 * File for organizing modules.
 *
 * @package Yaffo
 */

namespace NeboTheme\Yaffo\Modules;

use NeboTheme\Yaffo\Traits\Singleton;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Modules Manager class.
 *
 * Modules Manager for organizing modules.
 */
class Modules_Manager {
	use Singleton;

	/**
	 * Retrieve names modules.
	 *
	 * @return array
	 */
	protected static function get_modules_name() {
		return [
			'Plugin_Activator',
			'Importer',

			'Additional_Content',
			'Ajax_Search',
			'Back_To_Top',
			'Cookie_Bar',
			'Gutenberg',
			'Instagram',
			'Mailchimp',
			'Most_Popular',
			'Page_Fade',
			'Post_Infinite_Scroll',
			'Seo',
			'Skin_Manager',
			'Woocommerce',
		];
	}

	/**
	 * Constructor Modules Manager.
	 *
	 * @return void
	 */
	private function __construct() {
		static::instance_modules();
		$this->add_hooks();
	}

	/**
	 * Add Hooks.
	 *
	 * Initialize module hooks.
	 *
	 * @return void.
	 */
	private function add_hooks() {
		if ( is_admin() ) {
			add_action( 'admin_enqueue_scripts', [ $this, 'add_config' ], 9999 );
		} else {
			add_action( 'wp_enqueue_scripts', [ $this, 'add_config' ], 9999 );
		}
	}

	/**
	 * Get data to frontend of admin.
	 */
	public function add_config() {
		if ( is_admin() ) {
			wp_localize_script(
				'yaffo-admin',
				'nebothemeAdminModulesConfig',
				apply_filters( 'nebotheme_config_modules_admin', [] )
			);
		} else {
			wp_localize_script(
				'yaffo',
				'nebothemeModulesConfig',
				apply_filters( 'nebotheme_config_modules_frontend', [] )
			);
		}
	}

	/**
	 * Retrieve names modules.
	 *
	 * @return array
	 */
	protected static function get_modules_classes() {
		$classes_modules = [];

		foreach ( self::get_modules_name() as $module_name ) {
			$class_module = __NAMESPACE__ . "\\{$module_name}\\Module";

			$classes_modules[] = $class_module;
		}

		return $classes_modules;
	}

	/**
	 * Instance modules.
	 *
	 * @return void
	 */
	protected static function instance_modules() {
		foreach ( static::get_modules_classes() as $class_module ) {
			static::instance_module( $class_module );
		}
	}

	/**
	 * Instance module.
	 *
	 * @param string $class_module Class instanceof \NeboTheme\Modules\Base_Module.
	 * @return void
	 */
	public static function instance_module( $class_module ) {
		if ( ! class_exists( $class_module ) ) {
			return;
		}

		$class_module::pre_instance();

		if ( $class_module::is_active() ) {
			$class_module::instance();
		}
	}
}

Modules_Manager::instance();
