<?php
/**
 * Merlin WP
 * Better WordPress Theme Onboarding
 *
 * @package Yaffo
 */

namespace NeboTheme\Yaffo\Modules\Importer;

use NeboTheme\Yaffo\Theme;
use NeboTheme\Yaffo\Modules\Importer\Module as ImportManagerModule;
use \Merlin;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * {@inheritDoc}
 */
class Custom_Merlin extends Merlin {

	/**
	 * Get url to merlin installing.
	 */
	public function get_merlin_page_name() {
		return $this->merlin_url;
	}

	/**
	 * Check complete status.
	 */
	public function is_completed() {
		return get_option( "merlin_{$this->slug}_completed" );
	}

	/**
	 * {@inheritDoc}
	 */
	public function redirect() {}

	/**
	 * {@inheritDoc}
	 */
	public function admin_page() {
		// Do not proceed, if we're not on the right page.
		if ( ImportManagerModule::is_merlin_page() ) { //phpcs:ignore WordPress.Security.NonceVerification.Recommended
			wp_enqueue_style(
				'yaffo-merlin',
				Theme::get_style_url( 'merlin', ImportManagerModule::get_css_uri() ),
				[ 'merlin' ],
				wp_get_theme( 'yaffo' )->version,
				'screen'
			);

			wp_localize_script(
				'jquery',
				'nebothemeMerlin',
				[
					'l10n' => [
						'live_preview' => esc_html__( 'Live Preview', 'yaffo' ),
					],
				]
			);
		}

		parent::admin_page();
	}

	/**
	 * {@inheritDoc}
	 */
	protected function content() {
		parent::content();

		if ( count( $this->import_files ) > 1 ) {
			?>
			<script type="text/javascript">
				var $select = jQuery( '.merlin__select-control.js-merlin-demo-import-select' );
				var $selectWrapper = jQuery( '.merlin__select-control-wrapper' );
				var import_files = <?php echo wp_json_encode( $this->import_files ); ?>;
				var $itemPrev = jQuery();

				$select.on( 'change', function () {
					var value = $select.val();
					var import_file = import_files[ value ];

					if ( ! import_file ) {
						return;
					}

					var import_preview_image_url = import_file.import_preview_image_url;

					if ( ! import_preview_image_url ) {
						return;
					}

					var $item = jQuery( '<a />', {
						class: 'nebotheme-marlin-demo-preview',
						href: import_file.preview_url,
						target: '_blank',
						title: nebothemeMerlin.l10n.live_preview,
						html: [
							jQuery( '<div />', {
								class: 'nebotheme-marlin-demo-preview__overlay',
								html: '<i class="dashicons dashicons-visibility"></i>',
							} ),
							jQuery( '<img />', {
								src: import_preview_image_url,
							} ),
						],
					} );

					$selectWrapper.after( $item );

					$itemPrev.remove();

					$itemPrev = $item;
				} );

				$select.trigger( 'change' );
			</script>
			<?php
		}
	}
}
