<?php
/**
 * Module Instagram.
 *
 * @package Yaffo
 */

namespace NeboTheme\Yaffo\Modules\Instagram;

use NeboTheme\Yaffo\Modules\Base_Module;
use NeboTheme\Yaffo\Customize\Customize_Manager;
use NeboTheme\Yaffo\Sidebars\Sidebar_Manager;
use InstagramFeed\Builder\SBI_Db;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Module Instagram class.
 */
final class Module extends Base_Module {
	/**
	 * {@inheritDoc}
	 */
	public static function is_active() {
		return function_exists( '\sb_instagram_activate' );
	}

	/**
	 * {@inheritDoc}
	 */
	public static function pre_instance() {
		add_action( 'activated_plugin', function( $plugin ) {
			if ( 'instagram-feed/instagram-feed.php' !== $plugin ) {
				return;
			}

			static::plugin_set_options();
		} );

		add_action( 'after_switch_theme', [ __CLASS__, 'plugin_set_options' ] );
	}

	/**
	 * The function sets the default options to plugins.
	 */
	public static function plugin_set_options() {
		$instagram_settings = get_option( 'sb_instagram_settings', [] );

		if ( ! is_array( $instagram_settings ) ) {
			$instagram_settings = [];
		}

		$instagram_settings['disable_js_image_loading'] = 'on';

		update_option( 'sb_instagram_settings', $instagram_settings );
	}

	/**
	 * Add Hooks.
	 *
	 * Initialize module hooks.
	 *
	 * @return void.
	 */
	protected function add_hooks() {
		add_action( 'nebotheme_render_footer_start', [ $this, 'render_footer' ], 1 );
		add_filter( 'nebotheme_widgets_classes', [ $this, 'get_widgets_classes' ] );

		add_action( 'nebotheme_customize_fields', function() {
			foreach ( Sidebar_Manager::get_sidebars_list_default() as $sidebar_id => $sidebar_args ) {
				$setting_name = Sidebar_Manager::get_layout_name( $sidebar_id );

				Customize_Manager::add_field(
					[
						'type' => 'toggle',
						'settings' => "instagram_feed_{$setting_name}",
						'label' => esc_html__( 'Show Footer Instagram Section', 'yaffo' ),
						'section' => "layout_sidebar_{$sidebar_id}",
						'default' => true,
						'theme_export' => true,
					]
				);
			}
		} );
	}

	/**
	 * Retrieve widgets classes.
	 *
	 * @param string $widgets_classes The name of the class that registers the document type.
	 *               Full name with the namespace.
	 *
	 * @return array
	 */
	public function get_widgets_classes( $widgets_classes ) {
		$widgets_classes[] = __NAMESPACE__ . '\\Widgets\\Instagram';

		return $widgets_classes;
	}

	/**
	 * Check if instagram accounts is set.
	 *
	 * @return bool
	 */
	public static function is_render() {
		$exported_feeds = SBI_Db::feeds_query();

		return ! empty( $exported_feeds[0]['id'] );
	}

	/**
	 * Check if instagram accounts is set.
	 *
	 * @return bool
	 */
	public static function is_render_in_location() {
		$current_sidebar = Sidebar_Manager::get_sidebar_id_by_condition();
		$is_render = self::is_render();

		if ( $current_sidebar && ! nebotheme_get_tm( 'instagram_feed_' . Sidebar_Manager::get_layout_name( $current_sidebar ) ) ) {
			$is_render = false;
		}

		return $is_render;
	}


	/**
	 * Echoes instagram
	 */
	public static function render( $args = [] ) {
		if ( ! self::is_render() ) {
			return;
		}

		$exported_feeds = SBI_Db::feeds_query();

		$args['feed'] = $exported_feeds[0]['id'];
		$args['from_update'] = true;
		$args['followcolor'] = '';
		$args['followhovercolor'] = '';
		$args['followtextcolor'] = '';

		echo do_shortcode( '[instagram-feed ' . nebotheme_get_render_attrs( $args ) . ']' );
	}

	/**
	 * Echoes instagram in wide container.
	 */
	public function render_footer() {
		if ( ! self::is_render_in_location() ) {
			return;
		}

		$instagram_args = [
			'cols' => '6',
			'imagepadding' => '',
			'imageres' => 'medium',
			'num' => '6',
			'showbutton' => false,
			'showheader' => false,
		];

		?>
		<div class="nebotheme-instagram-content">
			<div class="grid-container wide-adaptive">
				<?php static::render( $instagram_args ); ?>
			</div>
		</div><!-- .nebotheme-instagram-content -->
		<?php
	}
}
