<?php
/**
 * Class widget twitter
 *
 * @package Yaffo
 */

namespace NeboTheme\Yaffo\Modules\Instagram\Widgets;

use NeboTheme\Yaffo\Modules\Instagram\Module as InstagramModule;
use NeboTheme\YaffoCore\Widget_Base;
use NeboTheme\Yaffo\Utils;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * {@inheritDoc}
 */
class Instagram extends Widget_Base {
	/**
	 * {@inheritDoc}
	 */
	public static function get_name() {
		return 'instagram';
	}

	/**
	 * {@inheritDoc}
	 */
	public function get_label() {
		return '⛅ ' . esc_html__( 'NeboTheme - Instagram', 'yaffo' );
	}

	/**
	 * {@inheritDoc}
	 */
	public function update( $new_instance, $old_instance ) {
		$instance = parent::update( $new_instance, $old_instance );

		$num = (int) $instance['num'];
		$cols = (int) $instance['cols'];

		if ( $num ) {
			$instance['num'] = min( max( $num, 1 ), 33 );
		} else {
			$instance['num'] = 6;
		}

		if ( $cols ) {
			$instance['cols'] = min( max( $cols, 1 ), 10 );
		} else {
			$instance['cols'] = 2;
		}

		return $instance;
	}

	/**
	 * Back end widget form.
	 *
	 * @see WP_Widget::form()
	 *
	 * @param array $instance Previously saved values from database.
	 */
	public function form( $instance ) {
		$instance = Utils::array_merge_safe( (array) $instance, [
			'title' => null,
			'cols' => 2,
			'num' => 6,
			'followtext' => esc_html__( 'Follow', 'yaffo' ),
		] );

		if ( null === $instance['title'] ) {
			$instance['title'] = esc_html__( 'Instagram', 'yaffo' );
		}

		?>
		<!-- Title -->
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>">
				<?php esc_html_e( 'Title', 'yaffo' ); ?>:
			</label>
			<input
				class="widefat"
				id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"
				name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>"
				type="text"
				value="<?php echo esc_attr( $instance['title'] ); ?>"
			/>
		</p>
		<!-- Num -->
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'num' ) ); ?>">
				<?php esc_html_e( 'Images', 'yaffo' ); ?>:
			</label>
			<input
				type="number"
				class="widefat"
				id="<?php echo esc_attr( $this->get_field_id( 'num' ) ); ?>"
				name="<?php echo esc_attr( $this->get_field_name( 'num' ) ); ?>"
				min="1"
				max="33"
				value="<?php echo esc_attr( $instance['num'] ); ?>"
				placeholder="<?php echo esc_attr( $instance['num'] ); ?>"
			/>
		</p>
		<!-- Cols -->
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'cols' ) ); ?>">
				<?php esc_html_e( 'Columns', 'yaffo' ); ?> 1 - 10:
			</label>
			<input
				type="number"
				class="widefat"
				id="<?php echo esc_attr( $this->get_field_id( 'cols' ) ); ?>"
				name="<?php echo esc_attr( $this->get_field_name( 'cols' ) ); ?>"
				min="1"
				max="10"
				value="<?php echo esc_attr( $instance['cols'] ); ?>"
				placeholder="<?php echo esc_attr( $instance['cols'] ); ?>"
			/>
		</p>
		<!-- Button Text -->
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'followtext' ) ); ?>">
				<?php esc_html_e( 'Text Follow Button', 'yaffo' ); ?>:
			</label>
			<input
				type="text"
				class="widefat"
				id="<?php echo esc_attr( $this->get_field_id( 'followtext' ) ); ?>"
				name="<?php echo esc_attr( $this->get_field_name( 'followtext' ) ); ?>"
				value="<?php echo esc_attr( $instance['followtext'] ); ?>"
			/>
		</p>
		<!-- Go to settings -->
		<p>
			<a target="_blank" href="<?php echo esc_url( admin_url( '/admin.php?page=sb-instagram-feed' ) ); ?>">
				<?php esc_html_e( 'Instagram Settings', 'yaffo' ); ?>
			</a>
		</p>
		<?php
	}

	/**
	 * {@inheritDoc}
	 */
	public function render( $args, $instance ) {
		$instance = Utils::array_merge_safe( (array) $instance, [
			'title' => null,
			'cols' => 2,
			'num' => 6,
			'followtext' => esc_html__( 'Follow', 'yaffo' ),
		] );

		InstagramModule::render( [
			'cols' => $instance['cols'],
			'num' => $instance['num'],
			'followtext' => $instance['followtext'],
			'imagepadding' => 0,
			'imageres' => 'thumb',
			'showbutton' => false,
			'showheader' => false,
		] );
	}
}
