<?php
/**
 * Module Most Popular.
 *
 * @package Yaffo
 */

namespace NeboTheme\Yaffo\Modules\Most_Popular;

use NeboTheme\Yaffo\Modules\Base_Module;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Module Most Popular class.
 */
final class Module extends Base_Module {
	const METADATA_KEY = 'post_views';

	/**
	 * {@inheritDoc}
	 */
	public static function is_active() {
		return class_exists( '\Post_Views_Counter' );
	}
	/**
	 * {@inheritDoc}
	 */
	public static function pre_instance() {
		add_action( 'activated_plugin', function( $plugin ) {
			if ( 'post-views-counter/post-views-counter.php' !== $plugin ) {
				return;
			}

			static::plugin_set_options();
		} );
		add_action( 'after_switch_theme', [ __CLASS__, 'plugin_set_options' ] );
	}

	/**
	 * The function sets the default options to plugins.
	 */
	public static function plugin_set_options() {
		$display_options = get_option( 'post_views_counter_settings_display' );

		if ( ! $display_options ) {
			return;
		}

		if ( ! empty( $display_options['post_types_display'] ) ) {
			$display_options['post_types_display'] = [];
		}

		if ( ! empty( $display_options['post_views_label'] ) ) {
			$display_options['post_views_label'] = '';
		}

		if ( ! empty( $display_options['page_types_display'] ) ) {
			$display_options['page_types_display'] = [];
		}

		$display_options['position'] = 'manual';
		$display_options['icon_class'] = '';

		update_option( 'post_views_counter_settings_display', $display_options );
	}

	/**
	 * Add Hooks.
	 *
	 * Initialize module hooks.
	 *
	 * @return void.
	 */
	protected function add_hooks() {
		add_filter( 'pvc_enqueue_styles', '__return_false' );
		add_filter( 'nebotheme_widgets_classes', [ __CLASS__, 'get_widgets_classes' ] );
		add_filter( 'pvc_available_post_types', function( $post_types ) {
			return array_intersect_key( $post_types, array_flip( [ 'post' ] ) );
		} );
		add_filter( 'nebotheme_single_post_meta_data_choices', function( $meta_data_options ) {
			$meta_data_options[ static::METADATA_KEY ] = esc_html__( 'Post Views', 'yaffo' );

			return $meta_data_options;
		} );
		add_filter( 'nebotheme_metadata_types_callbacks', function( $types_callbacks ) {
			$types_callbacks[ static::METADATA_KEY ] = [ __CLASS__, 'render_post_views' ];

			return $types_callbacks;
		} );
	}

	/**
	 * Retrieve widgets classes.
	 *
	 * @param string $widgets_classes The name of the class that registers the document type.
	 *               Full name with the namespace.
	 *
	 * @return array
	 */
	public static function get_widgets_classes( $widgets_classes ) {
		$widgets_classes[] = __NAMESPACE__ . '\\Widgets\\Most_Popular';

		return $widgets_classes;
	}

	/**
	 * Echoes post view.
	 */
	public static function render_post_views() {
		$views_count = pvc_get_post_views( get_the_ID() );

		echo '<div class="nebotheme-meta nebotheme-meta-post-views">';

		printf(
			esc_html(
				/* translators: number of views */
				_nx(
					'%1$s View',
					'%1$s Views',
					$views_count,
					'views',
					'yaffo'
				)
			),
			esc_html( number_format_i18n( $views_count ) )
		);

		echo '</div>';
	}
}
