<?php
/**
 * Class widget twitter
 *
 * @package Yaffo
 */

namespace NeboTheme\Yaffo\Modules\Most_Popular\Widgets;

use NeboTheme\Yaffo\Modules\Most_Popular\Module as PostViewsModule;
use NeboTheme\YaffoCore\Widget_Base;
use NeboTheme\Yaffo\Classes\WP_Query_Agent;
use NeboTheme\Yaffo\Utils;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * {@inheritDoc}
 */
class Most_Popular extends Widget_Base {
	/**
	 * {@inheritDoc}
	 */
	public static function get_name() {
		return 'most-popular';
	}

	/**
	 * {@inheritDoc}
	 */
	public function get_label() {
		return '⛅ ' . esc_html__( 'NeboTheme - Most Popular', 'yaffo' );
	}

	/**
	 * {@inheritDoc}
	 */
	public function update( $new_instance, $old_instance ) {
		$new_instance['view_count_show'] = Utils::get_if_isset( $new_instance, 'view_count_show', '' );

		$instance = parent::update( $new_instance, $old_instance );

		return $instance;
	}

	/**
	 * {@inheritDoc}
	 */
	public function form( $instance ) {
		$defaults = [
			'title' => esc_html__( 'Most Popular', 'yaffo' ),
			'showposts' => 3,
			'view_count_show' => 'on',
		];
		$instance = wp_parse_args( (array) $instance, $defaults );
		?>

		<!-- Title -->
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title', 'yaffo' ); ?>:</label>
			<input  type="text" class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>">
		</p>
		<!-- Number of posts -->
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'showposts' ) ); ?>">
				<?php esc_html_e( 'Number of posts to show', 'yaffo' ); ?>:
			</label>
			<input type="number" id="<?php echo esc_attr( $this->get_field_id( 'showposts' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'showposts' ) ); ?>" value="<?php echo esc_attr( $instance['showposts'] ); ?>" class="widefat" min="1" size="3">
		</p>
		<!-- Show View Count -->
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'view_count_show' ) ); ?>"><?php esc_html_e( 'Show View Count', 'yaffo' ); ?>:</label>
			<input type="checkbox" id="<?php echo esc_attr( $this->get_field_id( 'view_count_show' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'view_count_show' ) ); ?>" <?php checked( (bool) $instance['view_count_show'], true ); ?> />
		</p>
		<?php
	}

	/**
	 * {@inheritDoc}
	 */
	public function render( $args, $instance ) {
		$defaults = [
			'showposts' => 3,
			'view_count_show' => '',
		];
		$instance = array_replace_recursive( $defaults, (array) $instance );
		$args_posts = [
			'ignore_sticky_posts' => true,
			'nopaging' => false,
			'post_status' => 'publish',
			'showposts' => $instance['showposts'],
		];

		WP_Query_Agent::loop_start();

		echo '<div class="nebotheme-widget-post-list">';

		$posts = pvc_get_most_viewed_posts( $args_posts );

		foreach ( $posts as $post ) {
			setup_postdata( $GLOBALS['post'] =& $post ); // phpcs:ignore WordPress.WP.GlobalVariablesOverride.Prohibited, Squiz.PHP.DisallowMultipleAssignments.Found

			nebotheme_render_post_open( 'nebotheme-widget-post-list__item', false );

			/* Content */
			echo '<div class="nebotheme-widget-post-list__content">';

			if ( $instance['view_count_show'] ) {
				nebotheme_render_post_meta(
					[
						PostViewsModule::METADATA_KEY,
					]
				);
			}

			nebotheme_render_post_title(
				[
					'tag' => 'h4',
				]
			);

			echo '</div>';

			echo '<div class="nebotheme-widget-post-list__image-wrap">';

			nebotheme_render_thumbnail(
				[
					'size' => 'yaffo-small-square',
					'placeholder' => true,
				]
			);

			echo '</div>';

			nebotheme_render_post_close();
		}

		echo '</div>';

		WP_Query_Agent::loop_end();
	}
}
