<?php
/**
 * Module Page Fade.
 *
 * @package Yaffo
 */

namespace NeboTheme\Yaffo\Modules\Page_Fade;

use NeboTheme\Yaffo\Customize\Customize_Manager;
use NeboTheme\Yaffo\Modules\Base_Module;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Module Page Fade class.
 */
final class Module extends Base_Module {
	/**
	 * Add Hooks.
	 *
	 * Initialize module hooks.
	 *
	 * @return void.
	 */
	protected function add_hooks() {
		add_action( 'nebotheme_customize_fields', [ __CLASS__, 'customize_add_fields' ] );

		add_action( 'wp_body_open', [ __CLASS__, 'wp_body_open' ] );
		add_filter( 'body_class', [ __CLASS__, 'body_class' ] );

		add_action( 'wp_enqueue_scripts', [ __CLASS__, 'wp_enqueue_scripts' ] );
	}

	/**
	 * Add style.
	 */
	public static function wp_enqueue_scripts() {
		if ( ! static::is_enabled() ) {
			return;
		}

		wp_register_style( 'yaffo-page-fade', false, [], wp_get_theme()->get( 'Version' ), false );
		wp_enqueue_style( 'yaffo-page-fade' );

		$style = '.nebotheme-page-fade {
			position: fixed;
			pointer-events: none;
			background: var(--nebotheme-color-bg);
			width: 100%;
			top: var(--nebotheme-adminbar-space, 0px);
			height: calc(100% - var(--nebotheme-adminbar-space, 0px));
			transition: opacity .25s ease, visibility .25s;
			z-index: 99998;
			visibility: visible;
			opacity: 1;
		}';

		wp_add_inline_style( 'yaffo-page-fade', $style );
	}

	/**
	 * Check if enable.
	 *
	 * @return bool
	 */
	public static function is_enabled() {
		return nebotheme_get_tm( 'page_fade' );
	}

	/**
	 * Filter for body classes.
	 */
	public static function wp_body_open() {
		if ( ! static::is_enabled() ) {
			return;
		}

		echo '<div class="nebotheme-page-fade"></div>';
	}

	/**
	 * Filter for body classes.
	 */
	public static function body_class( array $body_classes ) {
		if ( static::is_enabled() ) {
			$body_classes[] = 'page-fade--enable';
		}

		return $body_classes;
	}

	/**
	 * Add fields to customize.
	 */
	public static function customize_add_fields() {
		Customize_Manager::add_field(
			[
				'type'        => 'toggle',
				'settings'    => 'page_fade',
				'label'       => esc_html__( 'Page Fading', 'yaffo' ),
				'description' => esc_html__( 'For smooth transitions between pages', 'yaffo' ),
				'section'     => 'miscellaneous',
				'default'     => false,
			]
		);
	}
}
