<?php
/**
 * Module Plugin Activator.
 *
 * @package Yaffo
 */

namespace NeboTheme\Yaffo\Modules\Plugin_Activator;

use \TGM_Plugin_Activation;
use NeboTheme\Yaffo\Admin\Admin_Menu;
use NeboTheme\Yaffo\Modules\Importer\Module as ImportManagerModule;
use NeboTheme\Yaffo\Modules\Base_Module;
use NeboTheme\Yaffo\Utils;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Module Plugin Activator.
 */
final class Module extends Base_Module {
	const MENU_SLUG = 'nebotheme-install-plugins';
	const MENU_SLUG_TGMPA = 'tgmpa-install-plugins';

	/**
	 * {@inheritDoc}
	 */
	public static function pre_instance() {
		require static::get_module_dir() . '/includes/tgmpa/class-tgm-plugin-activation.php';
	}

	/**
	 * {@inheritDoc}
	 */
	public static function is_active() {
		return class_exists( '\TGM_Plugin_Activation' );
	}

	/**
	 * Register Required Plugins
	 *
	 * @return void
	 */
	public function tgmpa_register() {
		$dir = static::get_module_dir();
		$plugins = [
			[
				'name' => esc_html__( 'Yaffo Core', 'yaffo' ),
				'slug' => 'yaffo-core',
				'source' => "{$dir}/includes/plugins/yaffo-core.zip",
				'required' => true,
				'version' => '1.0.33',
			],
			[
				'name' => esc_html__( 'Instagram Feed', 'yaffo' ),
				'slug' => 'instagram-feed',
				'required' => false,
			],
			[
				'name' => esc_html__( 'Envato Market', 'yaffo' ),
				'slug' => 'envato-market',
				'source' => 'https://envato.github.io/wp-envato-market/dist/envato-market.zip',
				'required' => true,
				'force_activation' => false,
			],
			[
				'name' => esc_html__( 'Contact Form 7', 'yaffo' ),
				'slug' => 'contact-form-7',
				'required' => false,
			],
			[
				'name' => esc_html__( 'Mailchimp for WordPress', 'yaffo' ),
				'slug' => 'mailchimp-for-wp',
				'required' => false,
			],
			[
				'name' => esc_html__( 'Post Views Counter', 'yaffo' ),
				'slug' => 'post-views-counter',
				'required' => false,
			],
			[
				'name' => esc_html__( 'WooCommerce', 'yaffo' ),
				'slug' => 'woocommerce',
				'required' => false,
			],
		];

		if ( ! ImportManagerModule::is_merlin_page() ) {
			$plugins[] = [
				'name' => esc_html__( 'Yoast SEO', 'yaffo' ),
				'slug' => 'wordpress-seo',
				'required' => false,
			];
		}

		$theme = wp_get_theme();

		$config = [
			'id' => $theme->template, // Unique ID for hashing notices for multiple instances of TGMPA.
			'default_path' => '', // Default absolute path to bundled plugins.
			'menu' => static::MENU_SLUG_TGMPA, // Menu slug.
			'has_notices' => ! Admin_Menu::is_page_dashboard(),
			'dismissable' => true, // If false, a user cannot dismiss the nag message.
			'dismiss_msg' => '', // If 'dismissable' is false, this message will be output at top of nag.
			'is_automatic' => true, // Automatically activate plugins after installation or not.
			'message' => '', // Message to output right before the plugins table.
		];

		tgmpa( $plugins, $config );
	}

	/**
	 * Add Hooks.
	 *
	 * Initialize module hooks.
	 *
	 * @return void
	 */
	protected function add_hooks() {
		add_action( 'admin_menu', [ $this, 'admin_menu' ] );
		add_action( 'tgmpa_register', [ $this, 'tgmpa_register' ] );
		add_action( 'admin_init', [ $this, 'redirect_actions' ] );
	}

	/**
	 * Get page url Plugin Activator.
	 *
	 * @return string
	 */
	public static function get_page_url() {
		return admin_url( 'themes.php?page=' . static::MENU_SLUG_TGMPA );
	}

	/**
	 * Check current page.
	 */
	public static function is_page_tgmpa() {
		return isset( $_GET['page'] ) && self::MENU_SLUG_TGMPA === $_GET['page']; // phpcs:ignore WordPress.Security.NonceVerification.Recommended
	}

	/**
	 * Add submenu to dashboard.
	 *
	 * @return void
	 */
	public function admin_menu() {
		$tgmpa = TGM_Plugin_Activation::get_instance();

		if ( $tgmpa->is_tgmpa_complete() ) {
			return;
		}

		add_submenu_page(
			Admin_Menu::MENU_SLUG,
			$tgmpa->strings['page_title'],
			$tgmpa->strings['menu_title'],
			'manage_options',
			static::MENU_SLUG,
			[ $this, 'redirect_tgmpa' ]
		);
	}

	/**
	 * Generate function that redirect page.
	 */
	public function redirect_tgmpa() {
		if ( ob_get_level() ) {
			ob_clean();
		}

		wp_safe_redirect( static::get_page_url() );

		exit;
	}

	/**
	 * Redirection for some aliases
	 */
	public function redirect_actions() {
		global $pagenow;

		$current_page = Utils::get_if_isset( $_GET, 'page' ); // phpcs:ignore WordPress.Security.NonceVerification.Recommended

		if ( ! $current_page || ! in_array( $pagenow, [ 'themes.php', 'admin.php' ], true ) ) {
			return;
		}

		if ( static::MENU_SLUG === $current_page ) {
			return $this->redirect_tgmpa();
		}
	}
}
