<?php
/**
 * Module Plugin Activator.
 *
 * @package Yaffo
 */

namespace NeboTheme\Yaffo\Modules\Post_Infinite_Scroll;

use NeboTheme\Yaffo\Customize\Customize_Manager;
use NeboTheme\Yaffo\Sidebars\Sidebar_Manager;
use NeboTheme\Yaffo\Modules\Base_Module;
use NeboTheme\Yaffo\Utils;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Module Post Infinite Scroll.
 */
final class Module extends Base_Module {

	/**
	 * {@inheritDoc}
	 */
	protected function add_hooks() {
		add_action( 'nebotheme_render_content_end', [ __CLASS__, 'render' ], 9999 );
		add_action( 'wp_ajax_nopriv_nebotheme_ajax_post_infinite_scroll', [ __CLASS__, 'ajax_render' ] );
		add_action( 'wp_ajax_nebotheme_ajax_post_infinite_scroll', [ __CLASS__, 'ajax_render' ] );

		add_action( 'nebotheme_customize_fields', [ $this, 'customize_layout_add_fields' ] );
	}

	/**
	 * Registration customizer fields.
	 *
	 * @return void
	 */
	public function customize_layout_add_fields() {
		Customize_Manager::add_field(
			[
				'type' => 'toggle',
				'settings' => 'post_infinite_scroll',
				'label' => esc_html__( 'Infinite Loading', 'yaffo' ),
				'section' => 'layout_sidebar_sidebar_post',
				'default' => false,
			]
		);

		Customize_Manager::add_field(
			[
				'type' => 'number',
				'label' => esc_html__( 'Number of Infinite Loaded', 'yaffo' ),
				'settings' => 'post_infinite_scroll_max',
				'min' => 1,
				'default' => 20,
				'max' => 100,
				'step' => 1,
				'on_frontend' => true,
				'section' => 'layout_sidebar_sidebar_post',
				'transport' => false,
				'active_callback' => [
					[
						'setting' => 'post_infinite_scroll',
						'value' => true,
					],
				],
			]
		);
	}

	/**
	 * Render
	 *
	 * @return void.
	 */
	public static function ajax_render() {
		if ( ! nebotheme_get_tm( 'post_infinite_scroll' ) ) {
			wp_die( '', '', [ 'response' => 400 ] );
		}

		if ( empty( $_POST['current_post_id'] ) ) {
			wp_die( '', '', [ 'response' => 400 ] );
		}

		global $post;

		$post_id = sanitize_text_field( wp_unslash( $_POST['current_post_id'] ) );

		if ( ! $post_id ) {
			wp_die( '', '', [ 'response' => 400 ] );
		}

		$post = get_post( $post_id );

		if ( ! $post ) {
			wp_die( '', '', [ 'response' => 400 ] );
		}

		$prev_post = get_previous_post();

		if ( ! $prev_post ) {
			wp_die( '', '', [ 'response' => 404 ] );
		}

		wp(
			[
				'p' => $prev_post->ID,
				'no_found_rows'  => true,
				'posts_per_page' => 1,
				'post_status'    => 'publish',
			]
		);

		$html = Utils::get_ob_html( function() {
			nebotheme_render_var_block_start();
			nebotheme_render_single();
			nebotheme_render_var_block_end();
		} );

		$document_title = Utils::get_ob_html( function() {
			echo wp_get_document_title();
		} );

		wp_send_json(
			[
				'post' => [
					'id' => $prev_post->ID,
					'document_title' => $document_title,
					'permalink' => get_permalink( $prev_post ),
				],
				'html' => $html,
			]
		);

	}

	/**
	 * Render
	 *
	 * @return void.
	 */
	public static function render() {
		if ( ! is_singular( 'post' ) || ! nebotheme_get_tm( 'post_infinite_scroll' ) ) {
			return;
		}

		?>
		<div class="nebotheme-single-infinite">
			<div class="nebotheme-single-infinite__inner">
				<svg class="nebotheme-single-infinite__spinner" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 100 100">
					<defs>
						<radialGradient id="nebotheme-gradient-svg" cx="0.5" cy="0.5" fx="0" fy="0" r="2">
							<stop offset="0%" stop-color="var(--nebotheme-color-primary)"></stop>
							<stop offset="100%" stop-color="var(--nebotheme-color-bg)"></stop>
						</radialGradient>
					</defs>
					<g>
						<circle cx="50" cy="50" r="40" stroke="url(#nebotheme-gradient-svg)" stroke-width="15" fill="none"></circle>
						<animateTransform attributeName="transform" type="rotate" values="0 50 50;360 50 50" times="0;1" dur="1s" repeatCount="indefinite"></animateTransform>
					</g>
				</svg>
			</div>
		</div>
		<?php
	}
}
