<?php
/**
 * Module Most Popular.
 *
 * @package Yaffo
 */

namespace NeboTheme\Yaffo\Modules\Seo;

use NeboTheme\Yaffo\Utils;
use NeboTheme\Yaffo\Headline;
use NeboTheme\Yaffo\Modules\Base_Module;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Module Most Popular class.
 */
final class Module extends Base_Module {

	/**
	 * {@inheritDoc}
	 */
	public static function is_active() {
		return function_exists( 'yoast_breadcrumb' );
	}
	/**
	 * {@inheritDoc}
	 */
	public static function pre_instance() {
		add_action( 'activated_plugin', function( $plugin ) {
			if ( 'wordpress-seo/wp-seo.php' !== $plugin ) {
				return;
			}

			static::plugin_set_options();
		} );
		add_action( 'after_switch_theme', [ __CLASS__, 'plugin_set_options' ] );
	}

	/**
	 * The function sets the default options to plugins.
	 */
	public static function plugin_set_options() {
		$display_options = get_option( 'wpseo_titles' );

		if ( ! $display_options ) {
			$display_options = [];
		}

		$display_options['breadcrumbs-sep'] = nebotheme_get_render_breadcrumbs_separator();

		update_option( 'wpseo_titles', $display_options );
	}

	/**
	 * CHeck if to render.
	 */
	public static function is_render_breadcrumb() {
		return self::is_active() && ! empty( get_option( 'wpseo_titles' )['breadcrumbs-enable'] );
	}

	/**
	 * Echoes breadcrumb.
	 */
	public static function render_breadcrumb( array $arguments = [] ) {
		if ( ! self::is_render_breadcrumb() ) {
			return;
		}

		if ( empty( $arguments ) ) {
			$arguments = [
				Utils::get_ob_html( [ Headline::class, 'render_before' ] ),
				Utils::get_ob_html( [ Headline::class, 'render_after' ] ),
			];
		}

		yoast_breadcrumb( ...$arguments );
	}
}
