<?php
/**
 * Module Skins Manager.
 *
 * @package Yaffo
 */

namespace NeboTheme\Yaffo\Modules\Skin_Manager;

use NeboTheme\Yaffo\Modules\Base_Module;
use NeboTheme\Yaffo\Customize\Customize_Manager;
use NeboTheme\Yaffo\Modules\Importer\Module as ImportManagerModule;
use NeboTheme\Yaffo\Admin\Admin_Menu;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Module Skins Manager.
 */
final class Module extends Base_Module {
	const SECTION_NAME = 'skin_manager';

	/**
	 * {@inheritDoc}
	 */
	protected function add_hooks() {
		add_action( 'admin_menu', [ __CLASS__, 'register_menu' ] );
		add_filter( 'kirki_control_types', [ __CLASS__, 'add_kirki_control_types' ] );
		add_action( 'nebotheme_customize_fields', [ __CLASS__, 'customize_add_fields' ] );
	}

	/**
	 * {@inheritDoc}
	 */
	public function get_config_customize() {
		return [
			'confirm_message' => esc_html__( 'Are you sure? The color and font settings will be currently lost!', 'yaffo' ),
		];
	}

	/**
	 * Add menu to dashboard.
	 */
	public static function register_menu() {
		if ( ! class_exists( '\Kirki' ) || ! ImportManagerModule::is_completed() ) {
			return;
		}

		add_submenu_page(
			Admin_Menu::MENU_SLUG,
			esc_html__( 'Skins', 'yaffo' ),
			esc_html__( 'Skins', 'yaffo' ),
			'manage_options',
			'customize.php?autofocus[section]=' . self::SECTION_NAME
		);
	}

	/**
	 * Add fields to customize.
	 */
	public static function customize_add_fields() {
		Customize_Manager::add_section(
			self::SECTION_NAME,
			[
				'title' => esc_html__( 'Skins', 'yaffo' ),
				'icon'  => 'dashicons-admin-customizer',
				'panel' => 'appearance',
			]
		);

		Customize_Manager::add_field(
			[
				'section'  => self::SECTION_NAME,
				'type'     => 'nebotheme-skin-manager',
				'settings' => 'skin_manager',
			]
		);
	}

	/**
	 * Register custom control for kirki.
	 *
	 * @return array
	 */
	public static function add_kirki_control_types( array $controls ) {
		$namespace = __NAMESPACE__ . '\\Controls\\';

		$controls['nebotheme-skin-manager'] = $namespace . 'Skin_Manager';

		return $controls;
	}
}
