<?php
/**
 * Module Twitter.
 *
 * @package Yaffo
 */

namespace NeboTheme\Yaffo\Modules\Twitter;

use NeboTheme\Yaffo\Modules\Twitter\Classes\TwitterUtils;
use NeboTheme\Yaffo\Modules\Base_Module;
use NeboTheme\Yaffo\Utils;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Module Twitter.
 */
final class Module extends Base_Module {
	const TWEETS_EXPIRATION = HOUR_IN_SECONDS;
	const ACCESS_TOKEN_EXPIRATION = 12 * HOUR_IN_SECONDS;

	/**
	 * Add Hooks.
	 *
	 * Initialize module hooks.
	 *
	 * @return void.
	 */
	protected function add_hooks() {
		add_filter( 'nebotheme_widgets_classes', [ $this, 'get_widgets_classes' ] );
	}

	/**
	 * Retrieve widgets classes.
	 *
	 * @param string $widgets_classes The name of the class that registers the document type.
	 *               Full name with the namespace.
	 *
	 * @return array
	 */
	public function get_widgets_classes( $widgets_classes ) {
		$widgets_classes[] = __NAMESPACE__ . '\\Widgets\\Twitter_Old';

		return $widgets_classes;
	}

	/**
	 * Retrieve username twitter from theme default.
	 *
	 * @return string
	 */
	public static function get_username_default() {
		return nebotheme_get_social_data( 'twitter', 'username_default' );
	}

	public static function get_tweets( $count = 5, $username = '' ) {
		if ( ! $username ) {
			$username = self::get_username_default();
		}

		$transient_prefix = 'nebotheme_yaffo_twitter';

		$transient_name_tweets = "{$transient_prefix}_{$username}_{$count}";
		$transient_name_access_token = "{$transient_prefix}_access_token";

		$twitter_cache = get_transient( $transient_name_tweets );

		if ( $twitter_cache ) {
			return $twitter_cache;
		}

		$access_token = get_transient( $transient_name_access_token );

		if ( ! $access_token ) {
			$args = [
				'method'      => 'POST',
				'httpversion' => '1.1',
				'blocking'    => true,
				'headers'     => [
					'Authorization' => 'Basic ' . static::get_environment()['authBasic'],
					'Content-Type'  => 'application/x-www-form-urlencoded;charset=UTF-8',
				],
				'body'        => [
					'grant_type' => 'client_credentials',
				],
			];

			$response = wp_remote_post( esc_url( 'https://api.twitter.com/oauth2/token', null, '' ), $args );
			$keys = json_decode( wp_remote_retrieve_body( $response ), true );
			$access_token = Utils::get_if_isset( $keys, 'access_token' );

			set_transient( $transient_name_access_token, $access_token, self::ACCESS_TOKEN_EXPIRATION );
		}

		// Get Data
		$args = [
			'httpversion' => '1.1',
			'blocking'    => true,
			'headers'     => [
				'Authorization' => "Bearer $access_token",
			],
		];

		$url = add_query_arg(
			[
				'screen_name'     => $username,
				'count'           => $count,
				'include_rts'     => false,
				'exclude_replies' => false,
			],
			'https://api.twitter.com/1.1/statuses/user_timeline.json'
		);

		$response = wp_remote_get( $url, $args );

		if ( ! is_wp_error( $response ) && wp_remote_retrieve_response_code( $response ) === 200 ) {
			$body = json_decode( wp_remote_retrieve_body( $response ), true );

			$twitter = TwitterUtils::get_parsed_twitter_data( $body );

			set_transient( $transient_name_tweets, $twitter, self::TWEETS_EXPIRATION );
		} else {
			$twitter = json_decode( wp_remote_retrieve_body( $response ), true );

			if ( ! isset( $twitter['errors'] ) ) {
				$twitter = [];

				$twitter['errors'][0]['message'] = 'Not available!';
			}
		}

		return $twitter;
	}
}
