<?php
/**
 * Twitter Helper
 *
 * @package Yaffo
 */

namespace NeboTheme\Yaffo\Modules\Twitter\Classes;

use NeboTheme\Yaffo\Utils;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/* Convert Twitter Text */
class TwitterUtils {
	private static function get_tweet_text( $tweet ) {
		if ( empty( $tweet['text'] ) ) {
			return '';
		}

		$tweet_text = $tweet['text'];

		$tweet_text = preg_replace( '/(https?)\:\/\/([a-z0-9\/\.\&\#\?\-\+\~\_\,]+)/i', '<a target="_blank" rel="nofollow" href="' . ( '$1://$2' ) . '">$1://$2</a>', $tweet_text );
		$tweet_text = preg_replace( '/\@([a-aA-Z0-9\.\_\-]+)/i', '<a target="_blank" rel="nofollow" href="https://twitter.com/$1">@' . '$1</a>', $tweet_text );
		$tweet_text = preg_replace( '/\#([a-záéíóúüñçA-ZÁÉÍÓÚÜÑÇ0-9\.\_\-]+)/i', '<a target="_blank" rel="nofollow" href="https://twitter.com/search?q\=$1">#$1</a>', $tweet_text );

		return $tweet_text;
	}

	private static function get_tweet_time( $tweet ) {
		if ( empty( $tweet['created_at'] ) ) {
			return '';
		}

		return sprintf(
			esc_html_x(
				'%s ago',
				'%s = human-readable time difference',
				'yaffo'
			),
			human_time_diff( strtotime( $tweet['created_at'] ), current_time( 'timestamp' ) )
		);
	}

	private static function get_tweet_url( $tweet ) {
		if ( empty( $tweet['id_str'] ) || empty( $tweet['user']['screen_name'] ) ) {
			return '#';
		}

		return "https://twitter.com/{$tweet['user']['screen_name']}/statuses/{$tweet['id_str']}";
	}

	public static function get_parsed_twitter_data( $tweets_raw ) {
		$twitter = [];

		if ( $tweets_raw && is_array( $tweets_raw ) ) {
			$user = $tweets_raw[0]['user'];
			$avatar = str_replace( '_normal.jpg', '_200x200.jpg', Utils::get_if_isset( $user, 'profile_image_url_https', '' ) );

			$twitter['user'] = [
				'url' => "https://twitter.com/{$user['screen_name']}",
				'name' => Utils::get_if_isset( $user, 'name', '' ),
				'screen_name' => Utils::get_if_isset( $user, 'screen_name', '' ),
				'avatar' => $avatar,
				'verified' => Utils::get_if_isset( $user, 'verified', '' ),
				'following' => (int) Utils::get_if_isset( $user, 'friends_count', 0 ),
				'followers' => (int) Utils::get_if_isset( $user, 'followers_count', 0 ),
			];

			foreach ( $tweets_raw as $tweet_raw ) {
				$text = self::get_tweet_text( $tweet_raw );

				if ( ! $text ) {
					continue;
				}

				$tweet = [
					'id' => $tweet_raw['id_str'],
					'text' => $text,
					'retweet_count' => (int) Utils::get_if_isset( $tweet_raw, 'retweet_count', 0 ),
					'favorite_count' => (int) Utils::get_if_isset( $tweet_raw, 'favorite_count', 0 ),
					'url' => self::get_tweet_url( $tweet_raw ),
					'time' => self::get_tweet_time( $tweet_raw ),
				];

				if ( isset( $tweet_raw['retweeted_status'] ) ) {
					if ( empty( $tweet['favorite_count'] ) && ! empty( $tweet_raw['retweeted_status']['favorite_count'] ) ) {
						$tweet['favorite_count'] = $tweet_raw['retweeted_status']['favorite_count'];
					}

					$tweet['retweeted_status'] = [
						'url' => self::get_tweet_url( $tweet_raw['retweeted_status'] ),
					];
				}

				$twitter['tweets'][] = $tweet;
			}
		}

		return $twitter;
	}
}
