<?php
/**
 * Module Woocommerce.
 *
 * @package Yaffo
 */

namespace NeboTheme\Yaffo\Modules\Woocommerce;

use NeboTheme\Yaffo\Blog_Main;
use NeboTheme\Yaffo\Homepage;
use NeboTheme\Yaffo\Modules\Base_Module;
use NeboTheme\Yaffo\Modules\Importer\Module as ImportManagerModule;
use NeboTheme\Yaffo\Sidebars\Sidebar_Manager;
use NeboTheme\Yaffo\Modules\Plugin_Activator\Module as PluginActivatorModule;
use NeboTheme\Yaffo\Modules\Seo\Module as SeoModule;
use NeboTheme\Yaffo\Theme;
use NeboTheme\Yaffo\Utils;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Module Woocommerce.
 */
final class Module extends Base_Module {

	const SIDEBAR_WOO = 'sidebar_woocommerce';
	const SIDEBAR_PRODUCT = 'sidebar_product';

	/**
	 * State render product.
	 *
	 * @var bool
	 */
	private static $is_rendering_products_cart = false;

	/**
	 * {@inheritDoc}
	 */
	public static function pre_instance() {
		static::fix_merlin_install_ajax();
	}

	/**
	 * {@inheritDoc}
	 */
	public static function is_active() {
		return class_exists( '\WooCommerce' );
	}

	/**
	 * {@inheritDoc}
	 */
	protected function add_hooks() {
		add_action( 'after_setup_theme', [ $this, 'theme_setup' ] );
		add_action( 'nebotheme_off_canvas_bottom_end', [ __CLASS__, 'render_cart' ] );
		add_action( 'nebotheme_sticky_last_start', [ __CLASS__, 'render_cart_products' ] );
		add_action( 'nebotheme_top_last_end', [ __CLASS__, 'render_cart_products' ] );
		add_action( 'wp_enqueue_scripts', [ $this, 'register_styles_scripts' ] );

		add_filter( 'nebotheme_additional_content_templates', [ $this, 'additional_content_templates' ] );
		add_filter( 'nebotheme_headline_is_active', [ $this, 'is_active_headline' ] );
		add_filter( 'nebotheme_sidebars_list_default', [ $this, 'sidebars_list_default' ] );
		add_filter( 'woocommerce_add_to_cart_fragments', [ $this, 'add_to_cart_fragments' ] );
		add_filter( 'woocommerce_breadcrumb_defaults', [ $this, 'breadcrumb_defaults' ] );
		add_filter( 'woocommerce_pagination_args', [ $this, 'get_pagination_args' ] );
		add_filter( 'woocommerce_product_review_comment_form_args', [ $this, 'comment_form_args' ] );
		add_filter( 'woocommerce_output_related_products_args', [ $this, 'related_products_args' ] );
		add_filter( 'woocommerce_widget_cart_is_hidden', [ $this, 'widget_cart_is_hidden' ] );
		add_filter( 'cei_export_option_keys', [ $this, 'export_option_keys' ] );
		add_filter( 'body_class', [ __CLASS__, 'set_body_class' ] );
		add_filter( 'woocommerce_shortcode_products_query', [ __CLASS__, 'shortcode_products_query' ], 10, 3 );
		add_filter( 'nebotheme_metadata_types_callbacks', function( $types_callbacks ) {
			$types_callbacks['product_price'] = [ __CLASS__, 'render_product_price' ];

			return $types_callbacks;
		} );
		add_filter( 'woocommerce_locate_template', [ $this, 'change_locate_template' ], 11, 2 );

		$this->fix_merlin_install();
	}

	/**
	 * Return the path of the template to include if it exists.
	 *
	 * @param string $template
	 * @param string $template_name
	 *
	 * @return string
	 */
	public function change_locate_template( $template, $template_name ) {
		if ( 'global/breadcrumb.php' === $template_name && SeoModule::is_render_breadcrumb() ) {
			$template = static::get_module_dir() . '/templates/woo-breadcrumb.php';
		}

		return $template;
	}

	/**
	 * Change shortcode products query.
	 *
	 * @param array $query
	 * @param array $attributes
	 * @param string $type
	 */
	public static function shortcode_products_query( $query, $attributes, $type ) {
		if ( 'products' === $type && Homepage::is_products_slider() && Homepage::is_enable_slider() ) {
			$slider_posts = Homepage::get_wp_query_slider()->posts;

			$query['post__not_in'] = nebotheme_wp_list_pluck( $slider_posts, 'ID' );
		}

		return $query;
	}

	/**
	 * Echoes product meta price.
	 */
	public static function render_product_price() {
		echo '<div class="nebotheme-meta nebotheme-meta-product-price">';

		woocommerce_template_loop_price();

		echo '</div>';
	}

	/**
	 * Fix error on importer page.
	 */
	public function fix_merlin_install() {
		if ( ! is_admin() || ! ImportManagerModule::is_merlin_page() ) {
			return;
		}

		$class_woo_loader = 'Automattic\WooCommerce\Admin\Loader';

		add_filter( 'woocommerce_enable_setup_wizard', '__return_false' );

		if ( class_exists( $class_woo_loader ) ) {
			remove_action( 'admin_head', [ $class_woo_loader, 'remove_notices' ] );
			remove_action( 'admin_head', [ $class_woo_loader, 'smart_app_banner' ] );

			add_filter( 'doing_it_wrong_trigger_error', function( $doing, $function ) {
				if ( 'get_current_page' === $function && $doing ) {
					$doing = false;
				}

				return $doing;
			}, 10, 2 );
		}
	}

	/**
	 * Shop cart on header.
	 */
	public function widget_cart_is_hidden( $is_hidden ) {
		if ( self::$is_rendering_products_cart ) {
			$is_hidden = false;
		}

		return $is_hidden;
	}

	/**
	 * Additional option to export.
	 */
	public function export_option_keys( array $option_keys ) {
		$option_keys[] = 'woocommerce_cart_page_id';
		$option_keys[] = 'woocommerce_checkout_page_id';
		$option_keys[] = 'woocommerce_myaccount_page_id';
		$option_keys[] = 'woocommerce_shop_page_id';

		return $option_keys;
	}

	/**
	 * Adds css class to body
	 *
	 * @param array $classes
	 *
	 * @return array
	 */
	public static function set_body_class( array $classes ) {
		$classes[] = 'nebotheme-woocommerce';

		return $classes;
	}

	/**
	 * Define array of Additional Content Templates.
	 */
	public function additional_content_templates( array $templates ) {
		$templates['product'] = [
			'label' => esc_html__( 'Product', 'yaffo' ),
			'condition' => 'is_product',
		];

		return $templates;
	}

	/**
	 * Set columns number for the related products.
	 */
	public function related_products_args( array $args ) {
		if ( Sidebar_Manager::is_active() ) {
			$args['columns'] = 3;
			$args['posts_per_page'] = 3;
		} else {
			$args['columns'] = 4;
			$args['posts_per_page'] = 4;
		}

		return $args;
	}

	/**
	 * Comment form arguments.
	 */
	public function comment_form_args( $comment_form ) {
		if ( wc_review_ratings_enabled() ) {
			$comment_form['comment_field'] = '<div class="comment-form-rating"><label for="rating">' . esc_html__( 'Your rating', 'yaffo' ) . ( wc_review_ratings_required() ? '&nbsp;<span class="required">*</span>' : '' ) . '</label><select name="rating" id="rating" required>
				<option value="">' . esc_html__( 'Rate&hellip;', 'yaffo' ) . '</option>
				<option value="5">' . esc_html__( 'Perfect', 'yaffo' ) . '</option>
				<option value="4">' . esc_html__( 'Good', 'yaffo' ) . '</option>
				<option value="3">' . esc_html__( 'Average', 'yaffo' ) . '</option>
				<option value="2">' . esc_html__( 'Not that bad', 'yaffo' ) . '</option>
				<option value="1">' . esc_html__( 'Very poor', 'yaffo' ) . '</option>
			</select></div>';
		}

		$comment_form['comment_field'] .= '<p class="comment-form-comment"><textarea id="comment" name="comment" cols="45" rows="10" placeholder="' . esc_html__( 'Your review', 'yaffo' ) . '*" required></textarea></p>';

		return $comment_form;
	}

	/**
	 * Pagination arguments.
	 */
	public function get_pagination_args( $args ) {
		return array_merge( $args, Blog_Main::get_public_pagination_args() );
	}

	/**
	 * Filter for args breadcrumb.
	 *
	 * @param array $args Arguments.
	 */
	public function breadcrumb_defaults( $args ) {
		$args['delimiter'] = nebotheme_get_render_breadcrumbs_separator();
		$args['before'] = '<span>';
		$args['after'] = '</span>';

		return $args;
	}

	/**
	 * Woocommerce Dynamic cart count update after ajax
	 */
	public function add_to_cart_fragments( $dynamic_count ) {
		$dynamic_count['.nebotheme-woo-cart__count'] = Utils::get_ob_html( function() {
			self::render_cart_count();
		} );

		return $dynamic_count;
	}

	/**
	 * Handles JavaScript and CSS detection.
	 */
	public function register_styles_scripts() {
		wp_enqueue_style( 'yaffo-woocommerce', Theme::get_style_url( 'frontend', static::get_css_uri() ), [ 'woocommerce-general' ], wp_get_theme( 'yaffo' )->version, 'screen' );
	}

	/**
	 * Check if the page is for woocommerce.
	 *
	 * @return bool
	 */
	public static function is_woocommerce_page() {
		return (
			is_woocommerce() ||
			is_account_page() ||
			is_add_payment_method_page() ||
			is_cart() ||
			is_checkout_pay_page() ||
			is_checkout() ||
			is_edit_account_page() ||
			is_lost_password_page() ||
			is_order_received_page() ||
			is_view_order_page()
		);
	}

	/**
	 * Check for headline render.
	 */
	public function is_active_headline( $is_active ) {
		if ( $is_active && is_woocommerce() ) {
			$is_active = false;
		}

		return $is_active;
	}

	/**
	 * Add Hooks.
	 */
	public function theme_setup() {
		add_theme_support( 'woocommerce', [
			'gallery_thumbnail_image_width' => 150,
			'single_image_width' => 600,
			'thumbnail_image_width' => 600,
		] );
		add_theme_support( 'wc-product-gallery-zoom' );
		add_theme_support( 'wc-product-gallery-lightbox' );
		add_theme_support( 'wc-product-gallery-slider' );
	}

	/**
	 * Add Hooks.
	 */
	public function sidebars_list_default( array $sidebars_list ) {
		$condition_callable_single = Sidebar_Manager::generate_condition_by_post_types( 'product' );

		$sidebars_list[ self::SIDEBAR_WOO ] = [
			'name' => esc_html__( 'WooCommerce', 'yaffo' ),
			'description' => esc_html__( 'Widgets in this area will be shown in left or right sidebar on shop, checkout, cart page.', 'yaffo' ),
			'side_panel' => true,
			'condition_callable' => function() use ( $condition_callable_single ) {
				return (
					(
						is_woocommerce() &&
						! $condition_callable_single()
					) ||
					is_cart() ||
					is_checkout() ||
					is_checkout_pay_page() ||
					is_account_page() ||
					is_view_order_page() ||
					is_edit_account_page() ||
					is_order_received_page() ||
					is_add_payment_method_page() ||
					is_lost_password_page()
				);
			},
		];

		$sidebars_list[ self::SIDEBAR_PRODUCT ] = [
			'name' => esc_html__( 'Open Product', 'yaffo' ),
			'description' => esc_html__( 'Widgets in this area will be shown in left or right sidebar on single product.', 'yaffo' ),
			'side_panel' => true,
			'condition_callable' => $condition_callable_single,
		];

		// Fix for archive & page.
		$sidebars_ids_to_fix = [
			Sidebar_Manager::SIDEBAR_ARCHIVE,
			Sidebar_Manager::SIDEBAR_PAGE,
		];

		foreach ( $sidebars_ids_to_fix as $sidebars_id ) {
			if (
				isset( $sidebars_list[ $sidebars_id ] ) &&
				isset( $sidebars_list[ $sidebars_id ]['condition_callable'] )
			) {
				$condition_callable = $sidebars_list[ $sidebars_id ]['condition_callable'];

				$sidebars_list[ $sidebars_id ]['condition_callable'] = function() use ( $condition_callable ) {
					return call_user_func( $condition_callable ) && ! self::is_woocommerce_page();
				};
			}
		}

		return $sidebars_list;
	}

	/**
	 * Echoes cart.
	 */
	public static function render_cart( $products = false ) {
		?>
		<div class="nebotheme-woo-cart">
			<a
				class="nebotheme-woo-cart__link"
				href="<?php echo esc_url( wc_get_cart_url() ); ?>"
				title="<?php esc_attr_e( 'View your shopping cart', 'yaffo' ); ?>"
			>
				<span class="icon nebotheme-icon-basket"></span>
				<?php self::render_cart_count(); ?>
			</a>
			<?php
			if ( $products && class_exists( 'WC_Widget_Cart' ) ) {
				self::$is_rendering_products_cart = true;

				the_widget(
					'WC_Widget_Cart',
					[
						'title' => false,
						'hide_if_empty' => true,
					],
					[
						'before_widget' => '<div class="widget %s">',
						'after_widget' => '</div>',
					]
				);

				self::$is_rendering_products_cart = false;
			}
			?>
		</div>
		<?php
	}

	/**
	 * Echoes cart with products.
	 */
	public static function render_cart_products() {
		self::render_cart( true );
	}

	/**
	 * Echoes cart count.
	 */
	public static function render_cart_count() {
		?>
		<span class="nebotheme-woo-cart__count"><?php echo esc_html( WC()->cart->get_cart_contents_count() ); ?></span>
		<?php
	}

	/**
	 * Fix error on importer page.
	 */
	public static function fix_merlin_install_ajax() {
		if ( ! is_admin() ) {
			return;
		}

		$page = isset( $_REQUEST['page'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['page'] ) ) : false; //phpcs:ignore WordPress.Security.NonceVerification.Recommended
		$action = isset( $_REQUEST['action'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['action'] ) ) : false; //phpcs:ignore WordPress.Security.NonceVerification.Recommended
		$plugin = isset( $_REQUEST['plugin'] ) ? $_REQUEST['plugin'] : []; //phpcs:ignore WordPress.Security.NonceVerification.Recommended, WordPress.Security.ValidatedSanitizedInput.InputNotSanitized, WordPress.Security.ValidatedSanitizedInput.MissingUnslash

		if (
			! $page ||
			! $action ||
			! $plugin ||
			! PluginActivatorModule::MENU_SLUG_TGMPA === $page ||
			! 'tgmpa-bulk-activate' === $action ||
			! in_array( 'woocommerce', $plugin, true ) ||
			get_transient( 'wc_installing' )
		) {
			return;
		}

		add_filter( 'woocommerce_create_pages', '__return_empty_array' );
	}
}
