<?php

namespace NeboTheme\YaffoCore;

use NeboTheme\YaffoCore\Traits\Singleton;

require_once YAFFO_CORE_PATH_INCLUDES . '/traits/trait-singleton.php';

final class Auto_Loader {
	use Singleton;

	const ALIAS_NAMESPACES = [
		'NeboTheme\\YaffoCore' => YAFFO_CORE_PATH_INCLUDES,
	];

	private function __construct() {
		$this->register();
	}

	private function register() {
		spl_autoload_register( [ $this, 'handler' ] );
	}

	public function handler( $class ) {
		foreach ( self::ALIAS_NAMESPACES as $alias_namespace => $alias_dir ) {
			if ( false === strpos( $class, $alias_namespace ) ) {
				continue;
			}

			break;
		}

		if ( empty( $alias_dir ) || empty( $alias_namespace ) ) {
			return;
		}

		// does the class use the namespace prefix?
		$len = strlen( $alias_namespace );
		if ( 0 !== strncmp( $alias_namespace, $class, $len ) ) {
			// no, move to the next registered auto-loader.
			return;
		}
		// get the relative class name.
		$relative_class = substr( $class, $len );
		$relative_class = str_replace( '_', '-', $relative_class );

		foreach ( [ 'class', 'trait', 'interface', '' ] as $type ) {
			$prefix_file = '' !== $type ? "{$type}-" : $type;
			$parts = explode( '\\', $relative_class );
			$last = array_pop( $parts );
			$parts[] = $prefix_file . $last;
			$file = implode( '\\', $parts );
			$file = preg_replace(
				[ '/([a-z])([A-Z])/', '/_/', '/\\\/' ],
				[ '$1-$2', '-', DIRECTORY_SEPARATOR ],
				$file
			);

			switch ( $type ) {
				case 'class':
					$exists = class_exists( $class );
					break;
				case 'trait':
					$exists = trait_exists( $class, true );
					break;
				case 'interface':
					$exists = interface_exists( $class );
					break;
			}

			if ( $exists ) {
				return;
			}

			// replace the namespace prefix with the base directory, replace namespace
			// separators with directory separators in the relative class name, append
			// with .php.
			$file = $alias_dir . str_replace( '\\', DIRECTORY_SEPARATOR, strtolower( $file ) ) . '.php';

			// if the file exists, require it.
			if ( is_readable( $file ) ) {
				require_once $file;
				return;
			}
		}
	}
}

Auto_Loader::instance();
