<?php
namespace NeboTheme\YaffoCore;

use NeboTheme\YaffoCore\Ajax_Select;
use NeboTheme\YaffoCore\Custom_Sidebars;
use NeboTheme\YaffoCore\Lazy_Load;
use NeboTheme\YaffoCore\Meta_Boxes;
use NeboTheme\YaffoCore\Traits\Singleton;
use NeboTheme\YaffoCore\Widgets_Manager;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * NeboTheme plugin.
 *
 * @since 1.0.0
 */
final class Plugin {
	use Singleton;

	/**
	 * Plugin constructor.
	 *
	 * @since 1.0.0
	 * @return void
	 */
	public function __construct() {
		$this->add_hooks();
	}

	/**
	 * Add action and filters.
	 *
	 * @since 1.0.0
	 * @return void
	 */
	private function add_hooks() {
		add_action( 'init', [ $this, 'init' ], 0 );
		add_action( 'nebotheme_blog_loop_start', [ $this, 'blog_loop_start' ] );
		add_action( 'nebotheme_blog_loop_end', [ $this, 'blog_loop_end' ] );
	}

	/**
	 * Init components.
	 *
	 * @since 1.0.0
	 * @return void
	 */
	private function init_components() {
		new Widgets_Manager();
		new Meta_Boxes();

		Ajax_Select::instance();
		Lazy_Load::instance();
		Custom_Sidebars::instance();
	}


	/**
	 * Init
	 *
	 * @since 1.0.0
	 * @return void
	 */
	public function init() {
		$this->init_components();
	}

	public function blog_loop_start() {
		add_filter( 'wp_get_attachment_image_attributes', [ $this, 'attachment_attrs' ], 10, 2 );

	}

	public function blog_loop_end() {
		remove_filter( 'wp_get_attachment_image_attributes', [ $this, 'attachment_attrs' ], 10, 2 );
	}

	/**
	 * Change attachments thumbnail post when in wp query.
	 */
	public function attachment_attrs( $attr, $attachment, $post = null ) {
		$post = get_post( $post );

		if ( $post ) {
			if ( empty( $attr['title'] ) ) {
				$attr['title'] = wp_strip_all_tags( $post->post_title ? $post->post_title : $attachment->post_title );
			}

			if ( empty( $attr['alt'] ) ) {
				$attr['alt'] = wp_strip_all_tags( $attachment->post_title ? $attachment->post_title : $post->post_title );
			}
		}

		return $attr;
	}
}

Plugin::instance();
