<?php
namespace NeboTheme\YaffoCore;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

final class Widgets_Manager {
	/**
	 * Plugin constructor.
	 *
	 * @since 1.0.0
	 * @return void
	 */
	public function __construct() {
		$this->add_hooks();
	}

	/**
	 * Add action and filters.
	 *
	 * @since 1.0.0
	 * @return void
	 */
	private function add_hooks() {
		add_action( 'widgets_init', [ $this, 'register_widget' ] );
	}

	/**
	 * Get widgets classes.
	 *
	 * @return array
	 */
	public static function get_widgets_classes() {
		return apply_filters( 'nebotheme_widgets_classes', [] );
	}


	/**
	 * Register widgets
	 *
	 * @since 1.0.0
	 * @return void
	 */
	public function register_widget() {

		/**
		 * Widget Classes.
		 *
		 * @since 1.0.0
		 *
		 * @param array string|WP_Widget.
		 */
		$widgets_classes = self::get_widgets_classes();

		if ( empty( $widgets_classes ) ) {
			return;
		}

		foreach ( $widgets_classes as $widget_class ) {
			if (
				! $widget_class ||
				! class_exists( $widget_class ) ||
				(
					method_exists( $widget_class, 'is_active' ) &&
					! call_user_func( [ $widget_class, 'is_active' ] )
				)
			) {
				continue;
			}

			register_widget( $widget_class );
		}
	}
}
