<?php

use NeboTheme\Yaffo\Utils;
use NeboTheme\Yaffo\Logos;

/**
 * Get image url for social sharing
 */
function nebotheme_get_share_image() {
	$image_url = '';

	if ( has_post_thumbnail() ) {
		$image_url = wp_get_attachment_url( get_post_thumbnail_id() );
	} else {
		$image_url_content = Utils::get_piece_text( '/<img.+src=[\'"]([^\'"]+)[\'"].*>/i', get_the_content() );

		if ( $image_url_content ) {
			$image_url = $image_url_content;
		} else {
			$image_url = Logos::get_logo_url( Logos::CUSTOM_LOGO_TM );
		}
	}

	return $image_url;
}

/**
 * Echoes share buttons
 *
 * @param array $args
 */
function yaffo_core_render_share_buttons( array $args = [] ) {
	$types_all = [
		'facebook' => esc_html__( 'Facebook', 'yaffo-core' ),
		'twitter' => esc_html__( 'Twitter', 'yaffo-core' ),
		'pinterest' => esc_html__( 'Pinterest', 'yaffo-core' ),
		'email' => esc_html__( 'Email', 'yaffo-core' ),
		'telegram' => esc_html__( 'Telegram', 'yaffo-core' ),
		'linkedin' => esc_html__( 'Linkedin', 'yaffo-core' ),
		'reddit' => esc_html__( 'Reddit', 'yaffo-core' ),
		'stumbleupon' => esc_html__( 'Stumbleupon', 'yaffo-core' ),
		'whatsapp' => esc_html__( 'Whatsapp', 'yaffo-core' ),
	];
	$args_default = [
		'before' => '',
		'separator_index' => 4,
		'types' => [],
	];

	if ( empty( $args['types'] ) ) {
		$user_types = nebotheme_get_tm( 'homepage_post_shares' );

		if ( $user_types ) {
			$args['types'] = $user_types;
		} else {
			$args['types'] = array_keys( $types_all );
		}
	}

	$args = array_merge( $args_default, $args );
	$share_text = nebotheme_get_tm( 'homepage_post_shares_text' );

	if ( ! $share_text ) {
		$share_text = esc_html__( 'Shares', 'yaffo-core' );
	}

	if ( $args['separator_index'] && count( $args['types'] ) > ( $args['separator_index'] + 1 ) ) {
		array_splice( $args['types'], $args['separator_index'], 0, 'separator' );
	}

	$args['before'] = $share_text;

	$settings = [
		'title' => esc_html( get_the_title() ),
		'text' => esc_html( get_the_excerpt() ),
		'image' => esc_url( nebotheme_get_share_image() ),
		'twitter_prefix_text' => esc_html__( 'Check out this article', 'yaffo-core' ),
		'url' => get_permalink(),
	];

	echo '<div class="nebotheme-share-buttons nebotheme-social-icons" data-settings="' . esc_attr( wp_json_encode( $settings ) ) . '">';

	if ( $args['before'] ) {
		echo '<span class="before">' .
			wp_kses_post( $args['before'] ) .
		'</span>';
	}

	echo '<div class="nebotheme-social-icons__inner">';

	foreach ( $args['types'] as $type ) {
		$icon = nebotheme_get_social_data( $type, 'icon' );
		$classes = [
			'nebotheme-share-buttons__item',
		];

		if ( $icon ) {
			$classes[] = $icon;
		}

		$attrs = [
			'class' => $classes,
			'href' => '#',
			'data-type' => $type,
			'title' => Utils::get_if_isset( $types_all, $type, null ),
		];

		echo '<a ' . nebotheme_get_render_attrs( $attrs ) . '></a>';
	}

	?>
		</div>
	</div>
	<?php
}
