<?php
namespace NeboTheme\YaffoCore\Traits;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}


/**
 * Singleton trait.
 *
 * Ensures only one instance of the trait base class is loaded
 * or can be loaded.
 *
 * @since 1.0.0
 */
trait Singleton {

	/**
	 * Base class instance.
	 *
	 * Holds the trait base class instance.
	 *
	 * @since 1.0.0
	 * @static
	 *
	 * @var array Array with instance of the base class.
	 */
	private static $instance = [];

	/**
	 * Get instance of base class.
	 *
	 * Ensures only one instance of the base class is loaded or can be loaded.
	 *
	 * @since 1.0.0
	 * @static
	 *
	 * @return object Single instance of the base class.
	 */
	public static function instance() {
		if ( ! self::$instance ) {
			self::$instance = new self();
		}

		return self::$instance;
	}
}
