<?php // phpcs:ignore WordPress.Files.FileName.InvalidClassFileName
/**
 * Plugin Name: Yaffo Core
 * Description: Yaffo Core Plugin
 * Plugin URI: https://nebotheme.com/yaffo/
 * Author: NeboTheme
 * Version: 1.0.33
 * Author URI: https://nebotheme.com/
 * Text Domain: yaffo-core
 * Domain Path: /languages/
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

define( 'YAFFO_CORE__FILE__', __FILE__ );
define( 'YAFFO_CORE_PATH', rtrim( plugin_dir_path( YAFFO_CORE__FILE__ ), DIRECTORY_SEPARATOR ) );
define( 'YAFFO_CORE_URL', plugins_url( '', YAFFO_CORE__FILE__ ) );
define( 'YAFFO_CORE_BASENAME', plugin_basename( YAFFO_CORE__FILE__ ) );
define( 'YAFFO_CORE_PATH_INCLUDES', YAFFO_CORE_PATH . '/includes' );

/**
 * NeboTheme initial class.
 *
 * The plugin file that checks all the plugin requirements and
 * run main plugin class.
 *
 * @since 1.0.1
 */
final class Yaffo_Core {

	/**
	 * Addon initial class constructor.
	 *
	 * Initializing the Addon initial file class.
	 *
	 * @since 1.0.0
	 *
	 * @return void
	 */
	public function __construct() {
		$this->register_auto_loader();

		add_action( 'admin_init', [ $this, 'check_compatibility' ] );
		add_action( 'init', [ $this, 'i18n' ] );
		add_action( 'plugins_loaded', [ $this, 'init' ] );

		register_activation_hook( YAFFO_CORE__FILE__, [ $this, 'activate' ] );
		register_deactivation_hook( YAFFO_CORE__FILE__, [ $this, 'deactivate' ] );
	}

	/**
	 * Register auto-loader.
	 *
	 * Addon auto-loader loads all the plugin files.
	 *
	 * @since 1.0.0
	 *
	 * @return void
	 */
	private function register_auto_loader() {
		require_once YAFFO_CORE_PATH_INCLUDES . '/class-auto-loader.php';
	}

	/**
	 * Load plugin localization files.
	 *
	 * Fired by `init` action hook.
	 *
	 * @since 1.0.0
	 *
	 * @return void
	 */
	public function i18n() {
		load_plugin_textdomain( 'yaffo-core', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
	}

	/**
	 * Initialize the plugin
	 *
	 * @since 1.0.0
	 *
	 * @return void
	 */
	public function init() {
		$this->require_plugin();
	}

	/**
	 * Require plugin.
	 *
	 * Initialize Addon main plugin handler class.
	 *
	 * @since 1.0.0
	 *
	 * @return void
	 */
	private function require_plugin() {
		require YAFFO_CORE_PATH_INCLUDES . '/class-plugin.php';
		require YAFFO_CORE_PATH_INCLUDES . '/functions-core.php';
	}

	/**
	 * Check compatibility.
	 *
	 * @since 1.0.0
	 *
	 * @return void
	 */
	public function check_compatibility() {
		if ( $this->is_theme_activate() || ! is_plugin_active( YAFFO_CORE_BASENAME ) ) {
			return;
		}

		deactivate_plugins( YAFFO_CORE_BASENAME );
		add_action( 'admin_notices', [ $this, 'compatibility_warning' ] );
	}

	/**
	 * Notice for compatibility.
	 */
	public function compatibility_warning() {
		?>
		<div class="notice notice-warning is-dismissible">
			<p>
				<strong>
					<?php esc_html_e( 'Yaffo Core plugin was deactivated, because your theme doesn\'t support it. Please use appropriate Yaffo theme.', 'yaffo-core' ); ?>
				</strong>
			</p>
		</div>
		<?php
	}

	public function activate() {
		$this->activation_compatibility();

		flush_rewrite_rules();
	}


	public function deactivate() {
		flush_rewrite_rules();
	}


	public function is_theme_activate() {
		return (
			defined( 'YAFFO_THEME' ) ||
			(
				defined( 'YAFFO_THEME' ) &&
				YAFFO_THEME
			)
		);
	}

	public function activation_compatibility() {
		if ( $this->is_theme_activate() ) {
			return;
		}

		deactivate_plugins( YAFFO_CORE_BASENAME );

		wp_die(
			esc_html__( 'Your theme doesn\'t support Yaffo Core plugin. Please use appropriate Yaffo theme.', 'yaffo-core' ),
			esc_html__( 'Error!', 'yaffo-core' ),
			[
				'back_link' => true,
			]
		);
	}
}

new Yaffo_Core();
